@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -39,21 +40,13 @@
 #include <IMark.hxx>
 #include <expfld.hxx>
 #include <swmodule.hxx>
-#ifndef _FLDREF_HXX
 #include <fldref.hxx>
-#endif
 #include <reffld.hxx>
 #include <wrtsh.hxx>
 
-#ifndef _FLDUI_HRC
 #include <fldui.hrc>
-#endif
-#ifndef _FLDTDLG_HRC
 #include <fldtdlg.hrc>
-#endif
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
 // --> OD 2007-11-14 #i83479#
 #include <SwNodeNum.hxx>
 #include <IDocumentMarkAccess.hxx>
@@ -72,16 +65,11 @@ SV_IMPL_PTRARR( _SwSeqFldList, _SeqFldLstElem* )
 #define REFFLDFLAG_NUMITEM  0x7200
 // <--
 
-USHORT	nFldDlgFmtSel		= 0;
+sal_uInt16	nFldDlgFmtSel		= 0;
 
 #define USER_DATA_VERSION_1 "1"
 #define USER_DATA_VERSION USER_DATA_VERSION_1
 
-
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SwFldRefPage::SwFldRefPage(Window* pParent, const SfxItemSet& rCoreSet ) :
     SwFldPage( pParent, SW_RES( TP_FLD_REF ), rCoreSet ),
 
@@ -124,16 +112,12 @@ SwFldRefPage::SwFldRefPage(Window* pParent, const SfxItemSet& rCoreSet ) :
     // --> OD 2007-11-21 #i83479#
     aSelectionToolTipLB.SetSelectHdl( LINK(this, SwFldRefPage, SubTypeHdl) );
     aSelectionToolTipLB.SetDoubleClickHdl( LINK(this, SwFldRefPage, InsertHdl) );
-    aSelectionToolTipLB.SetWindowBits( aSelectionToolTipLB.GetWindowBits() | WB_HSCROLL );
+    aSelectionToolTipLB.SetStyle( aSelectionToolTipLB.GetStyle() | WB_HSCROLL );
     aSelectionToolTipLB.SetSpaceBetweenEntries(1);
     aSelectionToolTipLB.SetHighlightRange();
     // <--
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SwFldRefPage::~SwFldRefPage()
 {
 }
@@ -148,7 +132,7 @@ void SwFldRefPage::SaveSelectedTxtNode()
         SvLBoxEntry* pEntry = aSelectionToolTipLB.GetCurEntry();
         if ( pEntry )
         {
-            const USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
+            const sal_uInt16 nTypeId = (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(GetTypeSel());
             SwWrtShell *pSh = GetWrtShell();
             if ( !pSh )
             {
@@ -156,7 +140,7 @@ void SwFldRefPage::SaveSelectedTxtNode()
             }
             if ( nTypeId == REFFLDFLAG_HEADING )
             {
-                mnSavedSelectedPos = static_cast<sal_uInt16>(reinterpret_cast<ULONG>(pEntry->GetUserData()));
+                mnSavedSelectedPos = static_cast<sal_uInt16>(reinterpret_cast<sal_uLong>(pEntry->GetUserData()));
                 if ( mnSavedSelectedPos < maOutlineNodes.size() )
                 {
                     mpSavedSelectedTxtNode = maOutlineNodes[mnSavedSelectedPos];
@@ -164,7 +148,7 @@ void SwFldRefPage::SaveSelectedTxtNode()
             }
             else if ( nTypeId == REFFLDFLAG_NUMITEM )
             {
-                mnSavedSelectedPos = static_cast<sal_uInt16>(reinterpret_cast<ULONG>(pEntry->GetUserData()));
+                mnSavedSelectedPos = static_cast<sal_uInt16>(reinterpret_cast<sal_uLong>(pEntry->GetUserData()));
                 if ( mnSavedSelectedPos < maNumItems.size() )
                 {
                     mpSavedSelectedTxtNode = maNumItems[mnSavedSelectedPos]->GetTxtNode();
@@ -186,10 +170,6 @@ sal_uInt16 SwFldRefPage::GetSavedSelectedPos() const
 
 // <--
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwFldRefPage::Reset(const SfxItemSet& )
 {
     if (!IsFldEdit())
@@ -201,21 +181,21 @@ void SwFldRefPage::Reset(const SfxItemSet& )
     }
     SetSelectionSel(LISTBOX_ENTRY_NOTFOUND);
     SetTypeSel(LISTBOX_ENTRY_NOTFOUND);
-    Init();	// Allgemeine initialisierung
+    Init();	// general initialisation
 
-    // TypeListBox initialisieren
-    aTypeLB.SetUpdateMode(FALSE);
+    // initialise TypeListBox 
+    aTypeLB.SetUpdateMode(sal_False);
     aTypeLB.Clear();
 
-    // Typ-Listbox fuellen
+    // fill Type-Listbox 
 
-    USHORT nPos;
-    // Referenz setzen / einfuegen
+    sal_uInt16 nPos;
+    // set/insert reference
     const SwFldGroupRgn& rRg = GetFldMgr().GetGroupRange(IsFldDlgHtmlMode(), GetGroup());
 
     for (short i = rRg.nStart; i < rRg.nEnd; ++i)
     {
-        const USHORT nTypeId = GetFldMgr().GetTypeId(i);
+        const sal_uInt16 nTypeId = GetFldMgr().GetTypeId(i);
 
         if (!IsFldEdit() || nTypeId != TYP_SETREFFLD)
         {
@@ -232,47 +212,47 @@ void SwFldRefPage::Reset(const SfxItemSet& )
     aTypeLB.SetEntryData(nPos, (void*)REFFLDFLAG_NUMITEM);
     // <--
 
-    // mit den Sequence-Typen auffuellen
+    // fill up with the sequence types
     SwWrtShell *pSh = GetWrtShell();
     if(!pSh)
         pSh = ::GetActiveWrtShell();
 
-    USHORT nFldTypeCnt = pSh->GetFldTypeCount(RES_SETEXPFLD);
+    sal_uInt16 nFldTypeCnt = pSh->GetFldTypeCount(RES_SETEXPFLD);
 
-    for (USHORT n = 0; n < nFldTypeCnt; ++n)
+    for (sal_uInt16 n = 0; n < nFldTypeCnt; ++n)
     {
         SwSetExpFieldType* pType = (SwSetExpFieldType*)pSh->GetFldType(n, RES_SETEXPFLD);
 
         if ((nsSwGetSetExpType::GSE_SEQ & pType->GetType()) && pType->GetDepends() && pSh->IsUsed(*pType))
         {
             nPos = aTypeLB.InsertEntry(pType->GetName());
-            aTypeLB.SetEntryData(nPos, (void*)(REFFLDFLAG | n));
+            aTypeLB.SetEntryData(nPos, (void*)(sal_uIntPtr)(REFFLDFLAG | n));
         }
     }
 
-    // Textmarken - jetzt immer (wegen Globaldokumenten)
+    // text marks - now always (because of globaldocuments)
     nPos = aTypeLB.InsertEntry(sBookmarkTxt);
     aTypeLB.SetEntryData(nPos, (void*)REFFLDFLAG_BOOKMARK);
 
-    // Fussnoten:
+    // footnotes:
     if( pSh->HasFtns() )
     {
         nPos = aTypeLB.InsertEntry(sFootnoteTxt);
         aTypeLB.SetEntryData(nPos, (void*)REFFLDFLAG_FOOTNOTE);
     }
 
-    // Endnoten:
+    // endnotes:
     if ( pSh->HasFtns(true) )
     {
         nPos = aTypeLB.InsertEntry(sEndnoteTxt);
         aTypeLB.SetEntryData(nPos, (void*)REFFLDFLAG_ENDNOTE);
     }
 
-    // alte Pos selektieren
+    // select old Pos
     if (!IsFldEdit())
         RestorePos(&aTypeLB);
 
-    aTypeLB.SetUpdateMode(TRUE);
+    aTypeLB.SetUpdateMode(sal_True);
 
     nFldDlgFmtSel = 0;
 
@@ -283,11 +263,11 @@ void SwFldRefPage::Reset(const SfxItemSet& )
                                 EqualsIgnoreCaseAscii(USER_DATA_VERSION_1))
         {
             String sVal = sUserData.GetToken(1, ';');
-            USHORT nVal = static_cast< USHORT >(sVal.ToInt32());
+            sal_uInt16 nVal = static_cast< sal_uInt16 >(sVal.ToInt32());
             if(nVal != USHRT_MAX)
             {
-                for(USHORT i = 0; i < aTypeLB.GetEntryCount(); i++)
-                    if(nVal == (USHORT)(ULONG)aTypeLB.GetEntryData(i))
+                for(sal_uInt16 i = 0; i < aTypeLB.GetEntryCount(); i++)
+                    if(nVal == (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(i))
                     {
                         aTypeLB.SelectEntryPos(i);
                         break;
@@ -307,33 +287,27 @@ void SwFldRefPage::Reset(const SfxItemSet& )
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldRefPage, TypeHdl, ListBox *, EMPTYARG )
 {
-    // Alte ListBoxPos sichern
-    const USHORT nOld = GetTypeSel();
+    // save old ListBoxPos 
+    const sal_uInt16 nOld = GetTypeSel();
 
-    // Aktuelle ListBoxPos
+    // current ListBoxPos
     SetTypeSel(aTypeLB.GetSelectEntryPos());
 
     if(GetTypeSel() == LISTBOX_ENTRY_NOTFOUND)
     {
         if (IsFldEdit())
         {
-            // Positionen selektieren
+            // select positions
             String sName;
-            USHORT nFlag = 0;
+            sal_uInt16 nFlag = 0;
 
             switch( GetCurField()->GetSubType() )
             {
                 case REF_BOOKMARK:
                 {
                     // --> OD 2007-11-14 #i83479#
-//                    sName = sBookmarkTxt;
-//                    nFlag = REFFLDFLAG_BOOKMARK;
                     SwGetRefField* pRefFld = dynamic_cast<SwGetRefField*>(GetCurField());
                     if ( pRefFld &&
                          pRefFld->IsRefToHeadingCrossRefBookmark() )
@@ -377,9 +351,9 @@ IMPL_LINK( SwFldRefPage, TypeHdl, ListBox *, EMPTYARG )
                     break;
             }
 
-            if (aTypeLB.GetEntryPos(sName) == LISTBOX_ENTRY_NOTFOUND)	// Referenz zu gel?schter Marke
+            if (aTypeLB.GetEntryPos(sName) == LISTBOX_ENTRY_NOTFOUND)	// reference to deleted mark
             {
-                USHORT nPos = aTypeLB.InsertEntry(sName);
+                sal_uInt16 nPos = aTypeLB.InsertEntry(sName);
                 aTypeLB.SetEntryData(nPos, reinterpret_cast<void*>(nFlag));
             }
 
@@ -395,12 +369,12 @@ IMPL_LINK( SwFldRefPage, TypeHdl, ListBox *, EMPTYARG )
 
     if (nOld != GetTypeSel())
     {
-        USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
+        sal_uInt16 nTypeId = (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(GetTypeSel());
 
-        // Auswahl-Listbox fuellen
+        // fill selection-ListBox 
         UpdateSubType();
 
-        BOOL bName = FALSE;     nFldDlgFmtSel = 0;
+        sal_Bool bName = sal_False;     nFldDlgFmtSel = 0;
 
         if ( ( !IsFldEdit() || aSelectionLB.GetEntryCount() ) &&
              nOld != LISTBOX_ENTRY_NOTFOUND )
@@ -412,25 +386,25 @@ IMPL_LINK( SwFldRefPage, TypeHdl, ListBox *, EMPTYARG )
         switch (nTypeId)
         {
             case TYP_GETREFFLD:
-                if (REFFLDFLAG & (USHORT)(ULONG)aTypeLB.GetEntryData(nOld))
-                    // dann bleibt die alte bestehen
+                if (REFFLDFLAG & (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(nOld))
+                    // the the old one stays
                     nFldDlgFmtSel = aFormatLB.GetSelectEntryPos();
-                bName = TRUE;
+                bName = sal_True;
                 break;
 
             case TYP_SETREFFLD:
-                bName = TRUE;
+                bName = sal_True;
                 break;
 
             case REFFLDFLAG_BOOKMARK:
-                bName = TRUE;
-                // kein break!!!
+                bName = sal_True;
+                // no break!!!
             default:
                 if( REFFLDFLAG & nTypeId )
                 {
-                    USHORT nOldId = (USHORT)(ULONG)aTypeLB.GetEntryData(nOld);
+                    sal_uInt16 nOldId = (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(nOld);
                     if( nOldId & REFFLDFLAG || nOldId == TYP_GETREFFLD )
-                        // dann bleibt die alte bestehen
+                        // then the old one stays
                         nFldDlgFmtSel = aFormatLB.GetSelectEntryPos();
                 }
                 break;
@@ -439,9 +413,9 @@ IMPL_LINK( SwFldRefPage, TypeHdl, ListBox *, EMPTYARG )
         aNameED.Enable(bName);
         aNameFT.Enable(bName);
 
-        // Format-Listbox fuellen
-        USHORT nSize = FillFormatLB(nTypeId);
-        BOOL bFormat = nSize != 0;
+        // fill Format-Listbox 
+        sal_uInt16 nSize = FillFormatLB(nTypeId);
+        sal_Bool bFormat = nSize != 0;
         aFormatLB.Enable(bFormat);
         aFormatFT.Enable(bFormat);
 
@@ -452,13 +426,9 @@ IMPL_LINK( SwFldRefPage, TypeHdl, ListBox *, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldRefPage, SubTypeHdl, ListBox *, EMPTYARG )
 {
-    USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
+    sal_uInt16 nTypeId = (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(GetTypeSel());
 
     switch(nTypeId)
     {
@@ -505,7 +475,7 @@ IMPL_LINK( SwFldRefPage, SubTypeHdl, ListBox *, EMPTYARG )
 }
 
 /*--------------------------------------------------------------------
-     Beschreibung: Typen in SelectionLB erneuern
+     Description: renew types in SelectionLB 
  --------------------------------------------------------------------*/
 
 void SwFldRefPage::UpdateSubType()
@@ -514,13 +484,13 @@ void SwFldRefPage::UpdateSubType()
     if(!pSh)
         pSh = ::GetActiveWrtShell();
     SwGetRefField* pRefFld = (SwGetRefField*)GetCurField();
-    const USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
+    const sal_uInt16 nTypeId = (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(GetTypeSel());
 
     String sOldSel;
     // --> OD 2007-11-22 #i83479#
     if ( aSelectionLB.IsVisible() )
     {
-        const USHORT nSelectionSel = aSelectionLB.GetSelectEntryPos();
+        const sal_uInt16 nSelectionSel = aSelectionLB.GetSelectEntryPos();
         if (nSelectionSel != LISTBOX_ENTRY_NOTFOUND)
         {
             sOldSel = aSelectionLB.GetEntry(nSelectionSel);
@@ -530,20 +500,20 @@ void SwFldRefPage::UpdateSubType()
     if (IsFldEdit() && !sOldSel.Len())
         sOldSel = String::CreateFromInt32( pRefFld->GetSeqNo() + 1 );
 
-    aSelectionLB.SetUpdateMode(FALSE);
+    aSelectionLB.SetUpdateMode(sal_False);
     aSelectionLB.Clear();
     // --> OD 2007-11-21 #i83479#
-    aSelectionToolTipLB.SetUpdateMode(FALSE);
+    aSelectionToolTipLB.SetUpdateMode(sal_False);
     aSelectionToolTipLB.Clear();
     bool bShowSelectionToolTipLB( false );
     // <--
 
     if( REFFLDFLAG & nTypeId )
     {
-        if (nTypeId == REFFLDFLAG_BOOKMARK)     // TextMarken!
+        if (nTypeId == REFFLDFLAG_BOOKMARK)     // text marks!
         {
             aSelectionLB.SetStyle(aSelectionLB.GetStyle()|WB_SORT);
-            // alle Textmarken besorgen
+            // get all text marks
             IDocumentMarkAccess* const pMarkAccess = pSh->getIDocumentMarkAccess();
             for(IDocumentMarkAccess::const_iterator_t ppMark = pMarkAccess->getBookmarksBegin();
                 ppMark != pMarkAccess->getBookmarksEnd();
@@ -560,9 +530,9 @@ void SwFldRefPage::UpdateSubType()
         {
             aSelectionLB.SetStyle(aSelectionLB.GetStyle() & ~WB_SORT);
             SwSeqFldList aArr;
-            USHORT nCnt = pSh->GetSeqFtnList( aArr );
+            sal_uInt16 nCnt = pSh->GetSeqFtnList( aArr );
 
-            for( USHORT n = 0; n < nCnt; ++n )
+            for( sal_uInt16 n = 0; n < nCnt; ++n )
             {
                 aSelectionLB.InsertEntry( aArr[ n ]->sDlgEntry );
                 if (IsFldEdit() && pRefFld->GetSeqNo() == aArr[ n ]->nSeqNo)
@@ -573,9 +543,9 @@ void SwFldRefPage::UpdateSubType()
         {
             aSelectionLB.SetStyle(aSelectionLB.GetStyle() & ~WB_SORT);
             SwSeqFldList aArr;
-            USHORT nCnt = pSh->GetSeqFtnList( aArr, true );
+            sal_uInt16 nCnt = pSh->GetSeqFtnList( aArr, true );
 
-            for( USHORT n = 0; n < nCnt; ++n )
+            for( sal_uInt16 n = 0; n < nCnt; ++n )
             {
                 aSelectionLB.InsertEntry( aArr[ n ]->sDlgEntry );
                 if (IsFldEdit() && pRefFld->GetSeqNo() == aArr[ n ]->nSeqNo)
@@ -647,7 +617,7 @@ void SwFldRefPage::UpdateSubType()
         else
         {
             aSelectionLB.SetStyle(aSelectionLB.GetStyle()|WB_SORT);
-            // zum Seq-FeldTyp die Felder besorgen:
+            // get the fields to Seq-FieldType:
 
             SwSetExpFieldType* pType = (SwSetExpFieldType*)pSh->GetFldType(
                                 nTypeId & ~REFFLDFLAG, RES_SETEXPFLD );
@@ -658,8 +628,8 @@ void SwFldRefPage::UpdateSubType()
                 if(IsFldEdit())
                     sOldSel.Erase();
 
-                USHORT nCnt = pType->GetSeqFldList( aArr );
-                for( USHORT n = 0; n < nCnt; ++n )
+                sal_uInt16 nCnt = pType->GetSeqFldList( aArr );
+                for( sal_uInt16 n = 0; n < nCnt; ++n )
                 {
                     aSelectionLB.InsertEntry( aArr[ n ]->sDlgEntry );
                     if (IsFldEdit() && !sOldSel.Len() &&
@@ -676,7 +646,7 @@ void SwFldRefPage::UpdateSubType()
     {
         SvStringsDtor aLst;
         GetFldMgr().GetSubTypes(nTypeId, aLst);
-        for (USHORT i = 0; i < aLst.Count(); ++i)
+        for (sal_uInt16 i = 0; i < aLst.Count(); ++i)
             aSelectionLB.InsertEntry(*aLst[i]);
 
         if (IsFldEdit())
@@ -688,9 +658,9 @@ void SwFldRefPage::UpdateSubType()
     aSelectionLB.Show( !bShowSelectionToolTipLB );
     if ( bShowSelectionToolTipLB )
     {
-        aSelectionToolTipLB.SetUpdateMode(TRUE);
+        aSelectionToolTipLB.SetUpdateMode(sal_True);
 
-        BOOL bEnable = aSelectionToolTipLB.GetEntryCount() != 0;
+        sal_Bool bEnable = aSelectionToolTipLB.GetEntryCount() != 0;
         aSelectionToolTipLB.Enable( bEnable );
         aSelectionFT.Enable( bEnable );
 
@@ -706,10 +676,10 @@ void SwFldRefPage::UpdateSubType()
     }
     else
     {
-        aSelectionLB.SetUpdateMode(TRUE);
+        aSelectionLB.SetUpdateMode(sal_True);
 
-        // Enable oder Disable
-        BOOL bEnable = aSelectionLB.GetEntryCount() != 0;
+        // enable or disable
+        sal_Bool bEnable = aSelectionLB.GetEntryCount() != 0;
         aSelectionLB.Enable( bEnable );
         aSelectionFT.Enable( bEnable );
 
@@ -720,29 +690,25 @@ void SwFldRefPage::UpdateSubType()
                 aSelectionLB.SelectEntryPos(0);
         }
 
-        if (IsFldEdit() && !aSelectionLB.GetSelectEntryCount()) // Falls die Referenz schon geloescht wurde...
+        if (IsFldEdit() && !aSelectionLB.GetSelectEntryCount()) // in case the reference was already deleted...
             aNameED.SetText(sOldSel);
     }
     // <--
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-USHORT SwFldRefPage::FillFormatLB(USHORT nTypeId)
+sal_uInt16 SwFldRefPage::FillFormatLB(sal_uInt16 nTypeId)
 {
     String sOldSel;
 
-    USHORT nFormatSel = aFormatLB.GetSelectEntryPos();
+    sal_uInt16 nFormatSel = aFormatLB.GetSelectEntryPos();
     if (nFormatSel != LISTBOX_ENTRY_NOTFOUND)
         sOldSel = aFormatLB.GetEntry(nFormatSel);
 
-    // Format-Listbox fuellen
+    // fill Format-Listbox 
     aFormatLB.Clear();
 
-    // Referenz hat weniger als die Beschriftung
-    USHORT nSize( 0 );
+    // refernce has less that the annotation
+    sal_uInt16 nSize( 0 );
     bool bAddCrossRefFormats( false );
     switch (nTypeId)
     {
@@ -762,16 +728,14 @@ USHORT SwFldRefPage::FillFormatLB(USHORT nTypeId)
 
         default:
             // --> OD 2007-11-16 #i83479#
-//            nSize = GetFldMgr().GetFormatCount( (REFFLDFLAG & nTypeId)
-//                                                    ? (USHORT)TYP_GETREFFLD : nTypeId,
-//                                                FALSE, IsFldDlgHtmlMode() );
+
             if ( REFFLDFLAG & nTypeId )
             {
                 nSize = FMT_REF_ONLYSEQNO - FMT_REF_BEGIN + 1;
             }
             else
             {
-                nSize = GetFldMgr().GetFormatCount( nTypeId, FALSE, IsFldDlgHtmlMode() );
+                nSize = GetFldMgr().GetFormatCount( nTypeId, sal_False, IsFldDlgHtmlMode() );
             }
             break;
     }
@@ -779,16 +743,16 @@ USHORT SwFldRefPage::FillFormatLB(USHORT nTypeId)
     if (REFFLDFLAG & nTypeId)
         nTypeId = TYP_GETREFFLD;
 
-    for (USHORT i = 0; i < nSize; i++)
+    for (sal_uInt16 i = 0; i < nSize; i++)
     {
-        USHORT nPos = aFormatLB.InsertEntry(GetFldMgr().GetFormatStr( nTypeId, i ));
+        sal_uInt16 nPos = aFormatLB.InsertEntry(GetFldMgr().GetFormatStr( nTypeId, i ));
         aFormatLB.SetEntryData( nPos, reinterpret_cast<void*>(GetFldMgr().GetFormatId( nTypeId, i )));
     }
     // --> OD 2007-11-16 #i83479#
     if ( bAddCrossRefFormats )
     {
-        USHORT nFormat = FMT_REF_NUMBER - FMT_REF_BEGIN;
-        USHORT nPos = aFormatLB.InsertEntry(GetFldMgr().GetFormatStr( nTypeId, nFormat ));
+        sal_uInt16 nFormat = FMT_REF_NUMBER - FMT_REF_BEGIN;
+        sal_uInt16 nPos = aFormatLB.InsertEntry(GetFldMgr().GetFormatStr( nTypeId, nFormat ));
         aFormatLB.SetEntryData( nPos, reinterpret_cast<void*>(GetFldMgr().GetFormatId( nTypeId, nFormat )));
         nFormat = FMT_REF_NUMBER_NO_CONTEXT - FMT_REF_BEGIN;
         nPos = aFormatLB.InsertEntry(GetFldMgr().GetFormatStr( nTypeId, nFormat ));
@@ -806,7 +770,7 @@ USHORT SwFldRefPage::FillFormatLB(USHORT nTypeId)
         if (!IsFldEdit())
             aFormatLB.SelectEntry(sOldSel);
         else
-            aFormatLB.SelectEntry(SW_RESSTR(FMT_REF_BEGIN + (USHORT)GetCurField()->GetFormat()));
+            aFormatLB.SelectEntry(SW_RESSTR(FMT_REF_BEGIN + (sal_uInt16)GetCurField()->GetFormat()));
 
         if (!aFormatLB.GetSelectEntryCount())
         {
@@ -820,21 +784,21 @@ USHORT SwFldRefPage::FillFormatLB(USHORT nTypeId)
 }
 
 /*--------------------------------------------------------------------
-    Beschreibung: Modify
+    Description: Modify
  --------------------------------------------------------------------*/
 
 IMPL_LINK( SwFldRefPage, ModifyHdl, Edit *, EMPTYARG )
 {
     String aName(aNameED.GetText());
-    const USHORT nLen = aName.Len();
+    const sal_uInt16 nLen = aName.Len();
 
-    BOOL bEnable = TRUE;
-    USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
+    sal_Bool bEnable = sal_True;
+    sal_uInt16 nTypeId = (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(GetTypeSel());
 
     if ((nTypeId == TYP_SETREFFLD && !GetFldMgr().CanInsertRefMark(aName)) ||
         (nLen == 0 && (nTypeId == TYP_GETREFFLD || nTypeId == TYP_SETREFFLD ||
                        nTypeId == REFFLDFLAG_BOOKMARK)))
-        bEnable = FALSE;
+        bEnable = sal_False;
 
     EnableInsert(bEnable);
 
@@ -843,24 +807,20 @@ IMPL_LINK( SwFldRefPage, ModifyHdl, Edit *, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
+sal_Bool SwFldRefPage::FillItemSet(SfxItemSet& )
 {
-    BOOL bModified = FALSE;
-    USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
+    sal_Bool bModified = sal_False;
+    sal_uInt16 nTypeId = (sal_uInt16)(sal_uLong)aTypeLB.GetEntryData(GetTypeSel());
 
-    USHORT nSubType = 0;
-    ULONG nFormat;
+    sal_uInt16 nSubType = 0;
+    sal_uLong nFormat;
 
     nFormat = aFormatLB.GetSelectEntryPos();
 
     if(nFormat == LISTBOX_ENTRY_NOTFOUND)
         nFormat = 0;
     else
-        nFormat = (ULONG)aFormatLB.GetEntryData((USHORT)nFormat);
+        nFormat = (sal_uLong)aFormatLB.GetEntryData((sal_uInt16)nFormat);
 
     String aVal(aValueED.GetText());
     String aName(aNameED.GetText());
@@ -868,7 +828,6 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
     switch(nTypeId)
     {
         case TYP_GETREFFLD:
-            // aName = aSelectionLB.GetSelectEntry();
             nSubType = REF_SETREFATTR;
             break;
 
@@ -876,7 +835,7 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
         {
             SwFieldType* pType = GetFldMgr().GetFldType(RES_SETEXPFLD, aName);
 
-            if(!pType)	// Nur einfuegen, wenn es den Namen noch nicht gibt
+            if(!pType)	// Only insert when the name doesn't exist yet
             {
                 aSelectionLB.InsertEntry(aName);
                 aSelectionLB.Enable();
@@ -895,18 +854,18 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
         {
             pSh = ::GetActiveWrtShell();
         }
-        if (nTypeId == REFFLDFLAG_BOOKMARK)		// TextMarken!
+        if (nTypeId == REFFLDFLAG_BOOKMARK)		// text marks!
         {
             aName = aNameED.GetText();
             nTypeId = TYP_GETREFFLD;
             nSubType = REF_BOOKMARK;
         }
-        else if (REFFLDFLAG_FOOTNOTE == nTypeId) 		// Fussnoten
+        else if (REFFLDFLAG_FOOTNOTE == nTypeId) 		// footnotes
         {
             SwSeqFldList aArr;
             _SeqFldLstElem aElem( aSelectionLB.GetSelectEntry(), 0 );
 
-            USHORT nPos;
+            sal_uInt16 nPos;
 
             nTypeId = TYP_GETREFFLD;
             nSubType = REF_FOOTNOTE;
@@ -917,17 +876,17 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
                 aVal = String::CreateFromInt32( aArr[nPos]->nSeqNo );
 
                 if (IsFldEdit() && aArr[nPos]->nSeqNo == pRefFld->GetSeqNo())
-                    bModified = TRUE; // Kann bei Feldern passieren, deren Referenz geloescht wurde
+                    bModified = sal_True; // can happen with fields of which the references were deleted
             }
             else if (IsFldEdit())
                 aVal = String::CreateFromInt32( pRefFld->GetSeqNo() );
         }
-        else if (REFFLDFLAG_ENDNOTE == nTypeId) 		// Endnoten
+        else if (REFFLDFLAG_ENDNOTE == nTypeId) 		// endnotes
         {
             SwSeqFldList aArr;
             _SeqFldLstElem aElem( aSelectionLB.GetSelectEntry(), 0 );
 
-            USHORT nPos;
+            sal_uInt16 nPos;
 
             nTypeId = TYP_GETREFFLD;
             nSubType = REF_ENDNOTE;
@@ -938,7 +897,7 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
                 aVal = String::CreateFromInt32( aArr[nPos]->nSeqNo );
 
                 if (IsFldEdit() && aArr[nPos]->nSeqNo == pRefFld->GetSeqNo())
-                    bModified = TRUE; // Kann bei Feldern passieren, deren Referenz geloescht wurde
+                    bModified = sal_True; // can happen with fields of which the reference was deleted
             }
             else if (IsFldEdit())
                 aVal = String::CreateFromInt32( pRefFld->GetSeqNo() );
@@ -947,11 +906,11 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
         else if ( nTypeId == REFFLDFLAG_HEADING )
         {
             SvLBoxEntry* pEntry = aSelectionToolTipLB.GetCurEntry();
-            ASSERT( pEntry,
+            OSL_ENSURE( pEntry,
                     "<SwFldRefPage::FillItemSet(..)> - no entry selected in selection tool tip listbox!" );
             if ( pEntry )
             {
-                const sal_uInt16 nOutlIdx( static_cast<sal_uInt16>(reinterpret_cast<ULONG>(pEntry->GetUserData())) );
+                const sal_uInt16 nOutlIdx( static_cast<sal_uInt16>(reinterpret_cast<sal_uLong>(pEntry->GetUserData())) );
                 pSh->getIDocumentOutlineNodesAccess()->getOutlineNodes( maOutlineNodes );
                 if ( nOutlIdx < maOutlineNodes.size() )
                 {
@@ -967,11 +926,11 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
         else if ( nTypeId == REFFLDFLAG_NUMITEM )
         {
             SvLBoxEntry* pEntry = aSelectionToolTipLB.GetCurEntry();
-            ASSERT( pEntry,
+            OSL_ENSURE( pEntry,
                     "<SwFldRefPage::FillItemSet(..)> - no entry selected in selection tool tip listbox!" );
             if ( pEntry )
             {
-                const sal_uInt16 nNumItemIdx( static_cast<sal_uInt16>(reinterpret_cast<ULONG>(pEntry->GetUserData())) );
+                const sal_uInt16 nNumItemIdx( static_cast<sal_uInt16>(reinterpret_cast<sal_uLong>(pEntry->GetUserData())) );
                 pSh->getIDocumentListItemsAccess()->getNumItems( maNumItems );
                 if ( nNumItemIdx < maNumItems.size() )
                 {
@@ -985,9 +944,9 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
             }
         }
         // <--
-        else                                // SeqenceFelder
+        else                                // SeqenceFields
         {
-            // zum Seq-FeldTyp die Felder besorgen:
+            // get fields for Seq-FeldType:
             SwSetExpFieldType* pType = (SwSetExpFieldType*)pSh->GetFldType(
                                     nTypeId & ~REFFLDFLAG, RES_SETEXPFLD );
             if( pType )
@@ -995,7 +954,7 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
                 SwSeqFldList aArr;
                 _SeqFldLstElem aElem( aSelectionLB.GetSelectEntry(), 0 );
 
-                USHORT nPos;
+                sal_uInt16 nPos;
 
                 nTypeId = TYP_GETREFFLD;
                 nSubType = REF_SEQUENCEFLD;
@@ -1006,7 +965,7 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
                     aVal = String::CreateFromInt32( aArr[nPos]->nSeqNo );
 
                     if (IsFldEdit() && aArr[nPos]->nSeqNo == pRefFld->GetSeqNo())
-                        bModified = TRUE; // Kann bei Feldern passieren, deren Referenz geloescht wurde
+                        bModified = sal_True; // can happen with fields of which the reference was deleted
                 }
                 else if (IsFldEdit())
                     aVal = String::CreateFromInt32( pRefFld->GetSeqNo() );
@@ -1030,44 +989,34 @@ BOOL SwFldRefPage::FillItemSet(SfxItemSet& )
         InsertFld( nTypeId, nSubType, aName, aVal, nFormat );
     }
 
-    ModifyHdl();	// Insert ggf enablen/disablen
+    ModifyHdl();	// enable/disable insert if applicable
 
-    return FALSE;
+    return sal_False;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SfxTabPage* SwFldRefPage::Create( 	Window* pParent,
                         const SfxItemSet& rAttrSet )
 {
     return ( new SwFldRefPage( pParent, rAttrSet ) );
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-USHORT SwFldRefPage::GetGroup()
+sal_uInt16 SwFldRefPage::GetGroup()
 {
     return GRP_REF;
 }
 
-/* -----------------12.01.99 10:09-------------------
- *
- * --------------------------------------------------*/
 void	SwFldRefPage::FillUserData()
 {
     String sData( String::CreateFromAscii(
                     RTL_CONSTASCII_STRINGPARAM( USER_DATA_VERSION )));
     sData += ';';
-    USHORT nTypeSel = aTypeLB.GetSelectEntryPos();
+    sal_uInt16 nTypeSel = aTypeLB.GetSelectEntryPos();
     if( LISTBOX_ENTRY_NOTFOUND == nTypeSel )
         nTypeSel = USHRT_MAX;
     else
-        nTypeSel = sal::static_int_cast< USHORT >(reinterpret_cast< sal_uIntPtr >(aTypeLB.GetEntryData( nTypeSel )));
+        nTypeSel = sal::static_int_cast< sal_uInt16 >(reinterpret_cast< sal_uIntPtr >(aTypeLB.GetEntryData( nTypeSel )));
     sData += String::CreateFromInt32( nTypeSel );
     SetUserData(sData);
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
