@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -47,15 +48,11 @@
 #include "swtypes.hxx"
 #include "swundo.hxx"
 #include "uitool.hxx"
-#include "undobj.hxx"
 #include "unomid.h"
 #include "view.hxx"
 #include "viewopt.hxx"
 #include "wrtsh.hxx"
 #include "wview.hxx"
-#include "swabstdlg.hxx"
-#include "chrdlg.hrc"
-
 
 #ifndef _SVSTDARR_HXX
 #define _SVSTDARR_STRINGSDTOR
@@ -82,7 +79,6 @@
 #include <svl/itemset.hxx>
 #include <svl/languageoptions.hxx>
 #include <svl/stritem.hxx>
-#include <svtools/filter.hxx>
 #include <svtools/langtab.hxx>
 #include <svx/dlgutil.hxx>
 #include <unotools/lingucfg.hxx>
@@ -90,6 +86,7 @@
 #include <vcl/msgbox.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/svapp.hxx>
+#include <sal/macros.h>
 
 #include <map>
 
@@ -110,12 +107,10 @@
 using namespace ::com::sun::star;
 using ::rtl::OUString;
 
-extern void lcl_CharDialog( SwWrtShell &rWrtSh, BOOL bUseDialog, USHORT nSlot,const SfxItemSet *pArgs, SfxRequest *pReq );
+extern void lcl_CharDialog( SwWrtShell &rWrtSh, sal_Bool bUseDialog, sal_uInt16 nSlot,const SfxItemSet *pArgs, SfxRequest *pReq );
 
 
-/*--------------------------------------------------------------------------
 
----------------------------------------------------------------------------*/
 
 // tries to determine the language of 'rText'
 //
@@ -178,10 +173,10 @@ LanguageType lcl_CheckLanguage(
         lang::Locale a3( SvxCreateLocale( aLangList[3] ) );
 #endif
 
-        INT32   nCount = sizeof(aLangList) / sizeof(aLangList[0]);
-        for (INT32 i = 0;  i < nCount;  i++)
+        sal_Int32 nCount = SAL_N_ELEMENTS(aLangList);
+        for (sal_Int32 i = 0; i < nCount;  i++)
         {
-            INT16 nTmpLang = aLangList[i];
+            sal_Int16 nTmpLang = aLangList[i];
             if (nTmpLang != LANGUAGE_NONE  &&  nTmpLang != LANGUAGE_DONTKNOW)
             {
                 if (xSpell->hasLanguage( nTmpLang ) &&
@@ -215,7 +210,7 @@ inline bool lcl_checkScriptType( sal_Int16 nScriptType, LanguageType nLang )
 
 void SwSpellPopup::fillLangPopupMenu(
     PopupMenu *pPopupMenu,
-    USHORT nLangItemIdStart,
+    sal_uInt16 nLangItemIdStart,
     uno::Sequence< OUString > aSeq,
     SwWrtShell* pWrtSh,
     std::map< sal_Int16, ::rtl::OUString > &rLangTable )
@@ -224,12 +219,12 @@ void SwSpellPopup::fillLangPopupMenu(
         return;
 
     SvtLanguageTable    aLanguageTable;
-    
+
     // set of languages to be displayed in the sub menus
     std::set< OUString > aLangItems;
 
     OUString    aCurLang( aSeq[0] );
-    USHORT      nScriptType = static_cast< sal_Int16 >(aSeq[1].toInt32());
+    sal_uInt16      nScriptType = static_cast< sal_Int16 >(aSeq[1].toInt32());
     OUString    aKeyboardLang( aSeq[2] );
     OUString    aGuessedTextLang( aSeq[3] );
 
@@ -285,7 +280,7 @@ void SwSpellPopup::fillLangPopupMenu(
         uno::Sequence< lang::Locale > rLocales( xDocumentLanguages->getDocumentLanguages( nScriptType, nMaxCount ) );
         if (rLocales.getLength() > 0)
         {
-            for (USHORT i = 0; i < rLocales.getLength(); ++i)
+            for (sal_uInt16 i = 0; i < rLocales.getLength(); ++i)
             {
                 if (aLangItems.size() == (size_t)nMaxCount)
                     break;
@@ -297,7 +292,7 @@ void SwSpellPopup::fillLangPopupMenu(
     }
 
 
-    USHORT nItemId = nLangItemIdStart;
+    sal_uInt16 nItemId = nLangItemIdStart;
     const OUString sAsterix(RTL_CONSTASCII_USTRINGPARAM("*"));  // multiple languages in current selection
     const OUString sEmpty;  // 'no language found' from language guessing
     std::set< OUString >::const_iterator it;
@@ -308,13 +303,13 @@ void SwSpellPopup::fillLangPopupMenu(
             aEntryTxt != sAsterix &&
             aEntryTxt != sEmpty)
         {
-            DBG_ASSERT( nLangItemIdStart <= nItemId && nItemId <= nLangItemIdStart + MN_MAX_NUM_LANG,
+            OSL_ENSURE( nLangItemIdStart <= nItemId && nItemId <= nLangItemIdStart + MN_MAX_NUM_LANG,
                     "nItemId outside of expected range!" );
             pPopupMenu->InsertItem( nItemId, aEntryTxt, MIB_RADIOCHECK );
             if (aEntryTxt == aCurLang)
             {
                 //make a check mark for the current language
-                pPopupMenu->CheckItem( nItemId, TRUE );
+                pPopupMenu->CheckItem( nItemId, sal_True );
             }
             rLangTable[ nItemId ] = aEntryTxt;
             ++nItemId;
@@ -332,9 +327,8 @@ static Image lcl_GetImageFromPngUrl( const OUString &rFileUrl )
     Image aRes;
     OUString aTmp;
     osl::FileBase::getSystemPathFromFileURL( rFileUrl, aTmp );
-//    ::rtl::OString aPath = OString( aTmp.getStr(), aTmp.getLength(), osl_getThreadTextEncoding() );
 #if defined(WNT)
-//    aTmp = lcl_Win_GetShortPathName( aTmp );
+
 #endif
     Graphic aGraphic;
     const String aFilterName( RTL_CONSTASCII_USTRINGPARAM( IMP_PNG ) );
@@ -353,7 +347,7 @@ OUString RetrieveLabelFromCommand( const OUString& aCmdURL )
     {
         try
         {
-            uno::Reference< container::XNameAccess > xNameAccess( ::comphelper::getProcessServiceFactory()->createInstance( OUString::createFromAscii("com.sun.star.frame.UICommandDescription") ), uno::UNO_QUERY );
+            uno::Reference< container::XNameAccess > xNameAccess( ::comphelper::getProcessServiceFactory()->createInstance( OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.UICommandDescription")) ), uno::UNO_QUERY );
             if ( xNameAccess.is() )
             {
                 uno::Reference< container::XNameAccess > xUICommandLabels;
@@ -368,7 +362,7 @@ OUString RetrieveLabelFromCommand( const OUString& aCmdURL )
                 {
                     for ( sal_Int32 i = 0; i < aPropSeq.getLength(); i++ )
                     {
-                        if ( aPropSeq[i].Name.equalsAscii( "Name" ))
+                        if ( aPropSeq[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Name" ) ) )
                         {
                             aPropSeq[i].Value >>= aStr;
                             break;
@@ -390,15 +384,14 @@ OUString RetrieveLabelFromCommand( const OUString& aCmdURL )
 SwSpellPopup::SwSpellPopup(
         SwWrtShell* pWrtSh,
         const uno::Reference< linguistic2::XSpellAlternatives >  &xAlt,
-        const String &rParaText ) :
-PopupMenu( SW_RES(MN_SPELL_POPUP) ),
-pSh( pWrtSh ),
-xSpellAlt(xAlt),
-bGrammarResults(false)
+        const String &rParaText
+)   : PopupMenu( SW_RES(MN_SPELL_POPUP) )
+    , pSh( pWrtSh )
+    , xSpellAlt(xAlt)
+    , bGrammarResults(false)
 {
-    DBG_ASSERT(xSpellAlt.is(), "no spelling alternatives available");
+    OSL_ENSURE(xSpellAlt.is(), "no spelling alternatives available");
 
-//    CreateAutoMnemonics();
     SetMenuFlags(MENU_FLAG_NOAUTOMNEMONICS);
 
     nCheckedLanguage = LANGUAGE_NONE;
@@ -410,7 +403,6 @@ bGrammarResults(false)
     sal_Int16 nStringCount = static_cast< sal_Int16 >( aSuggestions.getLength() );
 
     SvtLinguConfig aCfg;
-    const bool bHC = Application::GetSettings().GetStyleSettings().GetHighContrastMode();
 
     PopupMenu *pMenu = GetPopupMenu(MN_AUTOCORR);
     pMenu->SetMenuFlags(MENU_FLAG_NOAUTOMNEMONICS);
@@ -422,15 +414,15 @@ bGrammarResults(false)
         uno::Reference< container::XNamed > xNamed( xSpellAlt, uno::UNO_QUERY );
         if (xNamed.is())
         {
-            aSuggestionImageUrl = aCfg.GetSpellAndGrammarContextSuggestionImage( xNamed->getName(), bHC );
+            aSuggestionImageUrl = aCfg.GetSpellAndGrammarContextSuggestionImage( xNamed->getName() );
             aImage = Image( lcl_GetImageFromPngUrl( aSuggestionImageUrl ) );
         }
 
         InsertSeparator(0);
         bEnable = sal_True;
-        USHORT nAutoCorrItemId  = MN_AUTOCORR_START;
-        USHORT nItemId          = MN_SUGGESTION_START;
-        for (USHORT i = 0; i < nStringCount; ++i)
+        sal_uInt16 nAutoCorrItemId  = MN_AUTOCORR_START;
+        sal_uInt16 nItemId          = MN_SUGGESTION_START;
+        for (sal_uInt16 i = 0; i < nStringCount; ++i)
         {
             const String aEntry = aSuggestions[ i ];
             InsertItem( nItemId, aEntry, 0, i );
@@ -440,7 +432,7 @@ bGrammarResults(false)
 
             pMenu->InsertItem( nAutoCorrItemId, aEntry );
             pMenu->SetHelpId( nAutoCorrItemId, HID_LINGU_AUTOCORR);
-            
+
             ++nAutoCorrItemId;
             ++nItemId;
         }
@@ -449,7 +441,7 @@ bGrammarResults(false)
     OUString aIgnoreSelection( String( SW_RES( STR_IGNORE_SELECTION ) ) );
     OUString aSpellingAndGrammar = RetrieveLabelFromCommand( C2U(".uno:SpellingAndGrammarDialog") );
     SetItemText( MN_SPELLING_DLG, aSpellingAndGrammar );
-    USHORT nItemPos = GetItemPos( MN_IGNORE_WORD );
+    sal_uInt16 nItemPos = GetItemPos( MN_IGNORE_WORD );
     InsertItem( MN_IGNORE_SELECTION, aIgnoreSelection, 0, nItemPos );
     SetHelpId( MN_IGNORE_SELECTION, HID_LINGU_IGNORE_SELECTION);
 
@@ -473,9 +465,8 @@ bGrammarResults(false)
     }
 
     pMenu = GetPopupMenu(MN_ADD_TO_DIC);
-//    pMenu->CreateAutoMnemonics();
     pMenu->SetMenuFlags(MENU_FLAG_NOAUTOMNEMONICS);     //! necessary to retrieve the correct dictionary name in 'Execute' below
-    bEnable = FALSE;    // enable MN_ADD_TO_DIC?
+    bEnable = sal_False;    // enable MN_ADD_TO_DIC?
     uno::Reference< linguistic2::XDictionaryList >    xDicList( SvxGetDictionaryList() );
     if (xDicList.is())
     {
@@ -488,10 +479,10 @@ bGrammarResults(false)
 
         aDics = xDicList->getDictionaries();
         const uno::Reference< linguistic2::XDictionary >  *pDic = aDics.getConstArray();
-        USHORT nDicCount = static_cast< USHORT >(aDics.getLength());
+        sal_uInt16 nDicCount = static_cast< sal_uInt16 >(aDics.getLength());
 
-        USHORT nItemId = MN_DICTIONARIES_START;
-        for( USHORT i = 0; i < nDicCount; i++ )
+        sal_uInt16 nItemId = MN_DICTIONARIES_START;
+        for( sal_uInt16 i = 0; i < nDicCount; i++ )
         {
             uno::Reference< linguistic2::XDictionary >  xDicTmp( pDic[i], uno::UNO_QUERY );
             if (!xDicTmp.is() || SvxGetIgnoreAllList() == xDicTmp)
@@ -513,7 +504,7 @@ bGrammarResults(false)
                 if (xSvcInfo.is())
                 {
                     OUString aDictionaryImageUrl( aCfg.GetSpellAndGrammarContextDictionaryImage(
-                            xSvcInfo->getImplementationName(), bHC) );
+                            xSvcInfo->getImplementationName() ) );
                     if (aDictionaryImageUrl.getLength() > 0)
                     {
                         Image aImage( lcl_GetImageFromPngUrl( aDictionaryImageUrl ) );
@@ -561,25 +552,18 @@ bGrammarResults(false)
     pMenu = GetPopupMenu(MN_SET_LANGUAGE_PARAGRAPH);
     fillLangPopupMenu( pMenu, MN_SET_LANGUAGE_PARAGRAPH_START, aSeq, pWrtSh, aLangTable_Paragraph );
     EnableItem( MN_SET_LANGUAGE_PARAGRAPH, true );
-/*
-    pMenu = GetPopupMenu(MN_SET_LANGUAGE_ALL_TEXT);
-    fillLangPopupMenu( pMenu, MN_SET_LANGUAGE_ALL_TEXT_START, aSeq, pWrtSh, aLangTable_Document );
-    EnableItem( MN_SET_LANGUAGE_ALL_TEXT, true );
-*/
+
     uno::Reference< frame::XFrame > xFrame = pWrtSh->GetView().GetViewFrame()->GetFrame().GetFrameInterface();
     Image rImg = ::GetImage( xFrame,
-            OUString::createFromAscii(".uno:SpellingAndGrammarDialog"), sal_False,
-            Application::GetSettings().GetStyleSettings().GetHighContrastMode() );
+            OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:SpellingAndGrammarDialog")), sal_False );
     SetItemImage( MN_SPELLING_DLG, rImg );
 
     //////////////////////////////////////////////////////////////////////////////////
-    
-    RemoveDisabledEntries( TRUE, TRUE );
+
+    RemoveDisabledEntries( sal_True, sal_True );
 }
 
-/*--------------------------------------------------------------------------
 
----------------------------------------------------------------------------*/
 
 SwSpellPopup::SwSpellPopup(
     SwWrtShell *pWrtSh,
@@ -595,13 +579,12 @@ aInfo16( SW_RES(IMG_INFO_16) )
 {
     nCheckedLanguage = SvxLocaleToLanguage( rResult.aLocale );
 
-    USHORT nPos = 0;
+    sal_uInt16 nPos = 0;
     OUString aMessageText( rResult.aErrors[ nErrorInResult ].aShortComment );
     InsertSeparator( nPos++ );
     InsertItem( MN_SHORT_COMMENT, aMessageText, MIB_NOSELECT, nPos++ );
     SetItemImage( MN_SHORT_COMMENT, aInfo16 );
 
-//    CreateAutoMnemonics();
     SetMenuFlags(MENU_FLAG_NOAUTOMNEMONICS);
 
     InsertSeparator( nPos++ );
@@ -617,7 +600,7 @@ aInfo16( SW_RES(IMG_INFO_16) )
             aImage = Image( lcl_GetImageFromPngUrl( aSuggestionImageUrl ) );
         }
 
-        USHORT nItemId = MN_SUGGESTION_START;
+        sal_uInt16 nItemId = MN_SUGGESTION_START;
         for (sal_uInt16 i = 0;  i < nStringCount;  ++i)
         {
             const String aEntry = aSuggestions[ i ];
@@ -634,7 +617,7 @@ aInfo16( SW_RES(IMG_INFO_16) )
     OUString aIgnoreSelection( String( SW_RES( STR_IGNORE_SELECTION ) ) );
     OUString aSpellingAndGrammar = RetrieveLabelFromCommand( C2U(".uno:SpellingAndGrammarDialog") );
     SetItemText( MN_SPELLING_DLG, aSpellingAndGrammar );
-    USHORT nItemPos = GetItemPos( MN_IGNORE_WORD );
+    sal_uInt16 nItemPos = GetItemPos( MN_IGNORE_WORD );
     InsertItem( MN_IGNORE_SELECTION, aIgnoreSelection, 0, nItemPos );
     SetHelpId( MN_IGNORE_SELECTION, HID_LINGU_IGNORE_SELECTION);
 
@@ -645,7 +628,6 @@ aInfo16( SW_RES(IMG_INFO_16) )
     nGuessLangPara = LANGUAGE_NONE;
     if (xLG.is())
     {
-//        nGuessLangWord = lcl_CheckLanguage( xSpellAlt->getWord(), ::GetSpellChecker(), xLG, sal_False );
         nGuessLangPara = lcl_CheckLanguage( rParaText, ::GetSpellChecker(), xLG, sal_True );
     }
     if (nGuessLangWord != LANGUAGE_NONE || nGuessLangPara != LANGUAGE_NONE)
@@ -694,36 +676,26 @@ aInfo16( SW_RES(IMG_INFO_16) )
     pMenu = GetPopupMenu(MN_SET_LANGUAGE_PARAGRAPH);
     fillLangPopupMenu( pMenu, MN_SET_LANGUAGE_PARAGRAPH_START, aSeq, pWrtSh, aLangTable_Paragraph );
     EnableItem( MN_SET_LANGUAGE_PARAGRAPH, true );
-/*
-    pMenu = GetPopupMenu(MN_SET_LANGUAGE_ALL_TEXT);
-    fillLangPopupMenu( pMenu, MN_SET_LANGUAGE_ALL_TEXT_START, aSeq, pWrtSh, aLangTable_Document );
-    EnableItem( MN_SET_LANGUAGE_ALL_TEXT, true );
-*/
+
     uno::Reference< frame::XFrame > xFrame = pWrtSh->GetView().GetViewFrame()->GetFrame().GetFrameInterface();
     Image rImg = ::GetImage( xFrame,
-            OUString::createFromAscii(".uno:SpellingAndGrammarDialog"), sal_False,
-            Application::GetSettings().GetStyleSettings().GetHighContrastMode() );
+            OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:SpellingAndGrammarDialog")), sal_False );
     SetItemImage( MN_SPELLING_DLG, rImg );
 
     //////////////////////////////////////////////////////////////////////////////////
 
-    RemoveDisabledEntries( TRUE, TRUE );
+    RemoveDisabledEntries( sal_True, sal_True );
 }
 
-/*--------------------------------------------------------------------------
 
----------------------------------------------------------------------------*/
 sal_uInt16  SwSpellPopup::Execute( const Rectangle& rWordPos, Window* pWin )
 {
-//    SetMenuFlags(MENU_FLAG_NOAUTOMNEMONICS);
     sal_uInt16 nRet = PopupMenu::Execute(pWin, pWin->LogicToPixel(rWordPos));
     Execute( nRet );
     return nRet;
 }
-/*-- 19.01.2006 08:15:48---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
-void SwSpellPopup::Execute( USHORT nId )
+void SwSpellPopup::Execute( sal_uInt16 nId )
 {
     if (nId == USHRT_MAX)
         return;
@@ -736,7 +708,7 @@ void SwSpellPopup::Execute( USHORT nId )
     {
         sal_Int32 nAltIdx = (MN_SUGGESTION_START <= nId && nId <= MN_SUGGESTION_END) ?
                 nId - MN_SUGGESTION_START : nId - MN_AUTOCORR_START;
-        DBG_ASSERT( 0 <= nAltIdx && nAltIdx < aSuggestions.getLength(), "index out of range" );
+        OSL_ENSURE( 0 <= nAltIdx && nAltIdx < aSuggestions.getLength(), "index out of range" );
         if (0 <= nAltIdx && nAltIdx < aSuggestions.getLength() && (bGrammarResults || xSpellAlt.is()))
         {
             sal_Bool bOldIns = pSh->IsInsMode();
@@ -770,7 +742,7 @@ void SwSpellPopup::Execute( USHORT nId )
             pSh->DelLeft();
 
             pSh->Insert( aTmp );
-            
+
             /* #102505# EndAction/EndUndo moved down since insertion
                of temporary auto correction is now undoable two and
                must reside in the same undo group.*/
@@ -789,7 +761,7 @@ void SwSpellPopup::Execute( USHORT nId )
                of temporary auto correction is now undoable two and
                must reside in the same undo group.*/
             pSh->EndAction();
-            pSh->EndUndo(UNDO_UI_REPLACE);
+            pSh->EndUndo();
 
             pSh->SetInsMode( bOldIns );
         }
@@ -800,31 +772,30 @@ void SwSpellPopup::Execute( USHORT nId )
         {
             SvtLinguConfig().SetProperty( A2OU( UPN_IS_GRAMMAR_INTERACTIVE ), uno::makeAny( sal_True ));
         }
-        pSh->Left(CRSR_SKIP_CHARS, FALSE, 1, FALSE );
+        pSh->Left(CRSR_SKIP_CHARS, sal_False, 1, sal_False );
         {
             uno::Reference<linguistic2::XDictionaryList> xDictionaryList( SvxGetDictionaryList() );
             SvxDicListChgClamp aClamp( xDictionaryList );
             pSh->GetView().GetViewFrame()->GetDispatcher()->
                 Execute( FN_SPELL_GRAMMAR_DIALOG, SFX_CALLMODE_ASYNCHRON );
         }
-    }    
+    }
     else if (nId == MN_IGNORE_SELECTION)
     {
         SwPaM *pPaM = pSh->GetCrsr();
         if (pPaM)
             pSh->IgnoreGrammarErrorAt( *pPaM );
-    }    
+    }
     else if (nId == MN_IGNORE_WORD)
     {
         uno::Reference< linguistic2::XDictionary > xDictionary( SvxGetIgnoreAllList(), uno::UNO_QUERY );
         linguistic::AddEntryToDic( xDictionary,
                 xSpellAlt->getWord(), sal_False, aEmptyStr, LANGUAGE_NONE );
-    }    
+    }
     else if (MN_DICTIONARIES_START <= nId && nId <= MN_DICTIONARIES_END)
     {
             OUString aWord( xSpellAlt->getWord() );
-            //DBG_ASSERT( nDicIdx < aDics.getLength(), "dictionary index out of range" );
-            
+
             PopupMenu *pMenu = GetPopupMenu(MN_ADD_TO_DIC);
             String aDicName ( pMenu->GetItemText(nId) );
 
@@ -835,7 +806,7 @@ void SwSpellPopup::Execute( USHORT nId )
 
             if (xDic.is())
             {
-                INT16 nAddRes = linguistic::AddEntryToDic( xDic, aWord, FALSE, aEmptyStr, LANGUAGE_NONE );
+                sal_Int16 nAddRes = linguistic::AddEntryToDic( xDic, aWord, sal_False, aEmptyStr, LANGUAGE_NONE );
                 // save modified user-dictionary if it is persistent
                 uno::Reference< frame::XStorable >  xSavDic( xDic, uno::UNO_QUERY );
                 if (xSavDic.is())
@@ -849,18 +820,18 @@ void SwSpellPopup::Execute( USHORT nId )
                         nAddRes );
                 }
             }
-    }    
-    else 
+    }
+    else
     {
         // Set language for selection or for paragraph...
-        
+
         SfxItemSet aCoreSet( pSh->GetView().GetPool(),
                     RES_CHRATR_LANGUAGE,        RES_CHRATR_LANGUAGE,
                     RES_CHRATR_CJK_LANGUAGE,    RES_CHRATR_CJK_LANGUAGE,
                     RES_CHRATR_CTL_LANGUAGE,    RES_CHRATR_CTL_LANGUAGE,
                     0 );
         String aNewLangTxt;
-        
+
         if (MN_SET_LANGUAGE_SELECTION_START <= nId && nId <= MN_SET_LANGUAGE_SELECTION_END)
         {
             //Set language for current selection
@@ -889,7 +860,7 @@ void SwSpellPopup::Execute( USHORT nId )
             pSh->Push();        // save cursor
             SwLangHelper::SelectCurrentPara( *pSh );
             SwLangHelper::SetLanguage( *pSh, aNewLangTxt, true, aCoreSet );
-            pSh->Pop( FALSE );  // restore cursor
+            pSh->Pop( sal_False );  // restore cursor
         }
         else if (nId == MN_SET_PARA_NONE)
         {
@@ -897,7 +868,7 @@ void SwSpellPopup::Execute( USHORT nId )
             pSh->Push();        // save cursor
             SwLangHelper::SelectCurrentPara( *pSh );
             SwLangHelper::SetLanguage_None( *pSh, true, aCoreSet );
-            pSh->Pop( FALSE );  // restore cursor
+            pSh->Pop( sal_False );  // restore cursor
         }
         else if (nId == MN_SET_PARA_RESET)
         {
@@ -905,7 +876,7 @@ void SwSpellPopup::Execute( USHORT nId )
             pSh->Push();        // save cursor
             SwLangHelper::SelectCurrentPara( *pSh );
             SwLangHelper::ResetLanguages( *pSh, true );
-            pSh->Pop( FALSE );  // restore cursor
+            pSh->Pop( sal_False );  // restore cursor
         }
         else if (nId == MN_SET_PARA_MORE)
         {
@@ -913,27 +884,11 @@ void SwSpellPopup::Execute( USHORT nId )
             SwLangHelper::SelectCurrentPara( *pSh );
             //Open Format/Character Dialog
             lcl_CharDialog( *pSh, true, nId, 0, 0 );
-            pSh->Pop( FALSE );  // restore cursor
+            pSh->Pop( sal_False );  // restore cursor
         }
-#if 0
-        else if (nId == MN_SET_LANGUAGE_ALL_TEXT_START + nNumLanguageDocEntries - 1)
-        {
-            //Set Language_None as the default language
-            SwLangHelper::SetLanguage_None( *pSh, false, aCoreSet );
-        }
-        else if (nId == MN_SET_LANGUAGE_ALL_TEXT_START + nNumLanguageDocEntries)
-        {
-            // open the dialog "Tools/Options/Language Settings - Language"
-            SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
-            if (pFact)
-            {
-                VclAbstractDialog* pDlg = pFact->CreateVclDialog( pSh->GetView().GetWindow(), SID_LANGUAGE_OPTIONS );
-                pDlg->Execute();
-                delete pDlg;
-            }
-        }
-#endif
-    }    
+    }
 
     pSh->EnterStdMode();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
