@@ -2,7 +2,7 @@
  /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -29,8 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
-#include <string> // HACK: prevent conflict between STLPORT and Workshop headers
+#include <string>
 #include <stdlib.h>
 #include <hintids.hxx>
 #include <rtl/logfile.hxx>
@@ -40,7 +39,6 @@
 #include <svl/eitem.hxx>
 #include <unotools/undoopt.hxx>
 #include <unotools/lingucfg.hxx>
-#include <svtools/printdlg.hxx>
 #include <unotools/useroptions.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/request.hxx>
@@ -74,14 +72,15 @@
 #include <drformsh.hxx>
 #include <drwtxtsh.hxx>
 #include <beziersh.hxx>
+#include <navsh.hxx>
 #include <globdoc.hxx>
 #include <scroll.hxx>
-#include <globdoc.hxx>
 #include <navipi.hxx>
 #include <gloshdl.hxx>
 #include <usrpref.hxx>
 #include <srcview.hxx>
 #include <doc.hxx>
+#include <IDocumentUndoRedo.hxx>
 #include <drawdoc.hxx>
 #include <wdocsh.hxx>
 #include <wview.hxx>
@@ -95,7 +94,6 @@
 #include <frmui.hrc>
 #include <cfgitems.hxx>
 #include <prtopt.hxx>
-#include <swprtopt.hxx>
 #include <linguistic/lngprops.hxx>
 #include <editeng/unolingu.hxx>
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
@@ -118,7 +116,6 @@
 
 #include <svl/cjkoptions.hxx>
 
-
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
@@ -126,7 +123,6 @@ using namespace ::com::sun::star::scanner;
 using ::rtl::OUString;
 using ::rtl::OUStringBuffer;
 
-
 extern sal_Bool bNoInterrupt;		// in mainwn.cxx
 
 #define SWVIEWFLAGS ( SFX_VIEW_CAN_PRINT| 				\
@@ -148,7 +144,6 @@ sal_Bool			SwView::bExtra		= sal_False;
 sal_Bool			SwView::bFound		= sal_False;
 sal_Bool			SwView::bJustOpened	= sal_False;
 
-
 SvxSearchDialog*	SwView::pSrchDlg	= 0;
 SearchAttrItemList* SwView::pSrchList	= 0;
 SearchAttrItemList* SwView::pReplList	= 0;
@@ -178,7 +173,7 @@ void SwView::ImpSetVerb( int nSelType )
     }
     if ( bResetVerbs )
     {
-        SetVerbs( 0 );
+        SetVerbs( Sequence< embed::VerbDescriptor >() );
         bVerbsActive = sal_False;
     }
 }
@@ -209,6 +204,13 @@ void SwView::GotFocus() const
             const_cast< SwView* >( this )->AttrChangedNotify( pWrtShell );
         }
     }
+    if( GetWrtShellPtr() )
+    {
+        SwWrtShell& rWrtShell = GetWrtShell();
+        rWrtShell.GetDoc()->SetCurrentViewShell( GetWrtShellPtr() );
+        rWrtShell.GetDoc()->set( IDocumentSettingAccess::BROWSE_MODE,
+                                 rWrtShell.GetViewOptions()->getBrowseMode() );
+    }
 }
 
 /*--------------------------------------------------------------------
@@ -256,7 +258,7 @@ void SwView::SelectShell()
     }
     pLastTableFormat = pCurTableFmt;
 
-    //SEL_TBL und SEL_TBL_CELLS koennen verodert sein!
+    //SEL_TBL and SEL_TBL_CELLS can be changed!
     int nNewSelectionType = (pWrtShell->GetSelectionType()
                                 & ~nsSelectionType::SEL_TBL_CELLS);
 
@@ -277,13 +279,12 @@ void SwView::SelectShell()
         SfxDispatcher &rDispatcher = GetDispatcher();
         SwToolbarConfigItem *pBarCfg = SW_MOD()->GetToolbarConfig();
 
-    //	DELETEZ(pxSelectionObj); //Selektionsobjekt loeschen
         if ( pShell )
         {
             rDispatcher.Flush();		// alle gecachten Shells wirklich loeschen
 
             //Zur alten Selektion merken welche Toolbar sichtbar war
-            USHORT nId = static_cast< USHORT >( rDispatcher.GetObjectBarId( SFX_OBJECTBAR_OBJECT ));
+            sal_uInt16 nId = static_cast< sal_uInt16 >( rDispatcher.GetObjectBarId( SFX_OBJECTBAR_OBJECT ));
             if ( nId )
                 pBarCfg->SetTopToolbar( nSelectionType, nId );
 
@@ -309,7 +310,7 @@ void SwView::SelectShell()
             }
         }
 
-        BOOL bInitFormShell = sal_False;
+        sal_Bool bInitFormShell = sal_False;
         if (!pFormShell)
         {
             bInitFormShell = sal_True;
@@ -318,13 +319,17 @@ void SwView::SelectShell()
             StartListening(*pFormShell);
         }
 
-        BOOL bSetExtInpCntxt = sal_False;
+        sal_Bool bSetExtInpCntxt = sal_False;
         nSelectionType = nNewSelectionType;
         ShellModes eShellMode;
 
         if ( !( nSelectionType & nsSelectionType::SEL_FOC_FRM_CTRL ) )
             rDispatcher.Push( *pFormShell );
 
+        eShellMode = SHELL_MODE_NAVIGATION;
+        pShell = new SwNavigationShell( *this );
+        rDispatcher.Push( *pShell );
+
         if ( nSelectionType & nsSelectionType::SEL_OLE )
         {
             eShellMode = SHELL_MODE_OBJECT;
@@ -464,7 +469,7 @@ void SwView::SelectShell()
     if ( GetDocShell()->GetDoc()->IsOLEPrtNotifyPending() )
         GetDocShell()->GetDoc()->PrtOLENotify( sal_False );
 
-    //jetzt das Tabellen-Update
+    // now the table-update
     if(bUpdateTable)
         pWrtShell->UpdateTable();
 
@@ -496,7 +501,6 @@ IMPL_LINK( SwView, AttrChangedNotify, SwWrtShell *, EMPTYARG )
         GetDocShell()->IsReadOnly() )
         _CheckReadonlyState();
 
-    // JP 19.01.99: Cursor in Readonly Bereichen
     if( !pWrtShell->IsPaintLocked() && !bNoInterrupt )
         _CheckReadonlySelection();
 
@@ -524,26 +528,11 @@ IMPL_LINK( SwView, AttrChangedNotify, SwWrtShell *, EMPTYARG )
 
     }
 
-    //#i6193#, change ui if cursor is at a SwPostItField
+    // change ui if cursor is at a SwPostItField
     if (mpPostItMgr)
     {
-        // --> OD 2008-06-19 #i90516#
         // only perform the code that is needed to determine, if at the
         // actual cursor position is a post-it field
-//        SwRect aFldRect;
-//        SwContentAtPos aCntntAtPos( SwContentAtPos::SW_FIELD);
-//        if( pWrtShell->GetContentAtPos( pWrtShell->GetCrsrDocPos(), aCntntAtPos, FALSE, &aFldRect ) )
-//        {
-//            const SwField* pFld = aCntntAtPos.aFnd.pFld;
-//            if (pFld->Which()== RES_POSTITFLD)
-//            {
-//                mpPostItMgr->SetShadowState(reinterpret_cast<const SwPostItField*>(pFld));
-//            }
-//            else
-//                mpPostItMgr->SetShadowState(0);
-//        }
-//        else
-//            mpPostItMgr->SetShadowState(0);
         mpPostItMgr->SetShadowState( pWrtShell->GetPostItFieldAtCursor() );
     }
 
@@ -570,8 +559,8 @@ IMPL_LINK( SwView, TimeoutHdl, Timer *, EMPTYARG )
     _CheckReadonlyState();
     _CheckReadonlySelection();
 
-    BOOL bOldUndo = pWrtShell->DoesUndo();
-    pWrtShell->DoUndo( FALSE );
+    sal_Bool bOldUndo = pWrtShell->DoesUndo();
+    pWrtShell->DoUndo( sal_False );
     SelectShell();
     pWrtShell->DoUndo( bOldUndo );
     bAttrChgNotified = sal_False;
@@ -587,8 +576,8 @@ void SwView::_CheckReadonlyState()
     //Um erkennen zu koennen ob bereits disabled ist!
     SfxItemState eStateRO, eStateProtAll;
     const SfxPoolItem *pItem;
-    // JP 29.04.97: von einem nur uns bekannten Slot den Status abfragen.
-    //				Ansonsten kennen andere den Slot; wie z.B. die BasidIde
+    // von einem nur uns bekannten Slot den Status abfragen.
+    // Ansonsten kennen andere den Slot; wie z.B. die BasidIde
     eStateRO = rDis.QueryState( FN_INSERT_BOOKMARK, pItem );
     eStateProtAll = rDis.QueryState( FN_EDIT_REGION, pItem );
     sal_Bool bChgd = sal_False;
@@ -693,7 +682,7 @@ void SwView::_CheckReadonlySelection()
         case SHELL_MODE_TABLE_TEXT:
         case SHELL_MODE_TABLE_LIST_TEXT:
             {
-//JP 22.01.99: temporaere Loesung!!! Sollte bei jeder Cursorbewegung
+// temporaere Loesung!!! Sollte bei jeder Cursorbewegung
 //			den Font von der akt. Einfuegeposition setzen, also ausserhalb
 // 			dieses if's. Aber TH wertet den Font zur Zeit nicht aus und
 //			das besorgen erscheint mir hier zu teuer zu sein.
@@ -726,10 +715,9 @@ void SwView::_CheckReadonlySelection()
 
 SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
     : SfxViewShell( _pFrame, SWVIEWFLAGS ),
-
     aPageStr( SW_RES( STR_PAGE )),
     nNewPage(USHRT_MAX),
-    pNumRuleNodeFromDoc(0), // #i23726#
+    pNumRuleNodeFromDoc(0),
     pEditWin( new SwEditWin( &_pFrame->GetWindow(), *this ) ),
     pWrtShell(0),
     pShell(0),
@@ -766,11 +754,11 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
     nLastPasteDestination( 0xFFFF ),
     nLeftBorderDistance( 0 ),
     nRightBorderDistance( 0 ),
-    bInMailMerge(FALSE),
-    bInDtor(FALSE),
-    bOldShellWasPagePreView(FALSE)
+    bInMailMerge(sal_False),
+    bInDtor(sal_False),
+    bOldShellWasPagePreView(sal_False)
 {
-    // OD 18.12.2002 #103492# - According to discussion with MBA and further
+    // According to discussion with MBA and further
     // investigations, no old SfxViewShell will be set as parameter <pOldSh>,
     // if function "New Window" is performed to open an additional view beside
     // an already existing one.
@@ -786,8 +774,8 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
 
     bShowAtResize = bDrawSelMode = bDocSzUpdated = sal_True;
 
-    _CreateScrollbar( TRUE );
-    _CreateScrollbar( FALSE );
+    _CreateScrollbar( sal_True );
+    _CreateScrollbar( sal_False );
 
     pViewImpl = new SwView_Impl(this);
     SetName(C2S("View"));
@@ -796,7 +784,7 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
     aTimer.SetTimeout( 120 );
 
     SwDocShell* pDocSh = PTR_CAST( SwDocShell, _pFrame->GetObjectShell() );
-    BOOL bOldModifyFlag = pDocSh->IsEnableSetModified();
+    sal_Bool bOldModifyFlag = pDocSh->IsEnableSetModified();
     if(bOldModifyFlag)
         pDocSh->EnableSetModified( sal_False );
     OSL_ENSURE( pDocSh, "view without DocShell." );
@@ -807,57 +795,51 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
 
     //! get lingu options without loading lingu DLL
     SvtLinguOptions aLinguOpt;
-
     SvtLinguConfig().GetOptions( aLinguOpt );
-
     aUsrPref.SetOnlineSpell( aLinguOpt.bIsSpellAuto );
 
-    sal_Bool bOldShellWasSrcView = FALSE;
+    sal_Bool bOldShellWasSrcView = sal_False;
 
-    // OD 18.12.2002 #103492# - determine, if there is an existing view for
+    // determine if there is an existing view for
     // document
     SfxViewShell* pExistingSh = 0;
     if ( pOldSh )
+    {
         pExistingSh = pOldSh;
-    else
-    {
-        SfxViewFrame *pF = SfxViewFrame::GetFirst( pDocSh );
-        if( pF == _pFrame )
-            pF = SfxViewFrame::GetNext( *pF, pDocSh );
-        if( pF )
-            pExistingSh = pF->GetViewShell();
+        // determine type of existing view
+        if( pExistingSh->IsA( TYPE( SwPagePreView ) ) )
+        {
+            sSwViewData = ((SwPagePreView*)pExistingSh)->GetPrevSwViewData();
+            sNewCrsrPos = ((SwPagePreView*)pExistingSh)->GetNewCrsrPos();
+            nNewPage = ((SwPagePreView*)pExistingSh)->GetNewPage();
+            bOldShellWasPagePreView = sal_True;
+        }
+        else if( pExistingSh->IsA( TYPE( SwSrcView ) ) )
+            bOldShellWasSrcView = sal_True;
     }
 
-    // determine type of existing view
-    if( pExistingSh &&
-        pExistingSh->IsA( TYPE( SwPagePreView ) ) )
-    {
-        sSwViewData = ((SwPagePreView*)pExistingSh)->GetPrevSwViewData();
-        sNewCrsrPos = ((SwPagePreView*)pExistingSh)->GetNewCrsrPos();
-        nNewPage = ((SwPagePreView*)pExistingSh)->GetNewPage();
-        bOldShellWasPagePreView = TRUE;
-    }
-    else if( pExistingSh &&
-             pExistingSh->IsA( TYPE( SwSrcView ) ) )
-        bOldShellWasSrcView = TRUE;
-
     RTL_LOGFILE_CONTEXT_TRACE( aLog, "before create WrtShell" );
     if(PTR_CAST( SwView, pExistingSh))
     {
         pWrtShell = new SwWrtShell( *((SwView*)pExistingSh)->pWrtShell,
                                     pEditWin, *this);
-//MA: Das kann doch nur zu einem GPF fuehren!
-//		nSelectionType = ((SwView*)pOldSh)->nSelectionType;
+    }
+    else if( dynamic_cast<SwWrtShell*>( pDocSh->GetDoc()->GetCurrentViewShell() ) )
+    {
+        pWrtShell = new SwWrtShell( *(SwWrtShell*)pDocSh->GetDoc()->GetCurrentViewShell(),
+                                    pEditWin, *this);
     }
     else
     {
         SwDoc& rDoc = *((SwDocShell*)pDocSh)->GetDoc();
 
         if( !bOldShellWasSrcView && pWebDShell && !bOldShellWasPagePreView )
-            rDoc.set(IDocumentSettingAccess::BROWSE_MODE, true);
+            aUsrPref.setBrowseMode( sal_True );
+        else if( rDoc.IsLoaded() )
+            aUsrPref.setBrowseMode( rDoc.get(IDocumentSettingAccess::BROWSE_MODE) );
 
         //Fuer den BrowseMode wollen wir keinen Factor uebernehmen.
-        if( rDoc.get(IDocumentSettingAccess::BROWSE_MODE) && aUsrPref.GetZoomType() != SVX_ZOOM_PERCENT )
+        if( aUsrPref.getBrowseMode() && aUsrPref.GetZoomType() != SVX_ZOOM_PERCENT )
         {
             aUsrPref.SetZoomType( SVX_ZOOM_PERCENT );
             aUsrPref.SetZoom( 100 );
@@ -869,20 +851,20 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
             aUsrPref.SetViewLayoutColumns( 1 );
         }
         pWrtShell = new SwWrtShell( rDoc, pEditWin, *this, &aUsrPref );
-        //#97610# creating an SwView from a SwPagePreView needs to
+        // creating an SwView from a SwPagePreView needs to
         // add the ViewShell to the ring of the other ViewShell(s)
         if(bOldShellWasPagePreView)
         {
             ViewShell& rPreviewViewShell = *((SwPagePreView*)pExistingSh)->GetViewShell();
             pWrtShell->MoveTo(&rPreviewViewShell);
-            //#95521# to update the field command et.al. if necessary
+            // to update the field command et.al. if necessary
             const SwViewOption* pPreViewOpt = rPreviewViewShell.GetViewOptions();
             if( pPreViewOpt->IsFldName() != aUsrPref.IsFldName() ||
                     pPreViewOpt->IsShowHiddenField() != aUsrPref.IsShowHiddenField() ||
                     pPreViewOpt->IsShowHiddenPara() != aUsrPref.IsShowHiddenPara() ||
                     pPreViewOpt->IsShowHiddenChar() != aUsrPref.IsShowHiddenChar() )
                 rPreviewViewShell.ApplyViewOptions(aUsrPref);
-            // OD 09.01.2003 #106334# - reset design mode at draw view for form
+            // reset design mode at draw view for form
             // shell, if needed.
             if ( ((SwPagePreView*)pExistingSh)->ResetFormDesignMode() &&
                  pWrtShell->HasDrawView() )
@@ -894,16 +876,15 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
     }
     RTL_LOGFILE_CONTEXT_TRACE( aLog, "after create WrtShell" );
 
-    // --> OD 2005-02-11 #i38810# - assure that modified state of document
+    // assure that modified state of document
     // isn't reset, if document is already modified.
     const bool bIsDocModified = pWrtShell->GetDoc()->IsModified();
-    // <--
 
-    // JP 05.02.99: Bug 61495 - damit unter anderem das HLineal im
+    // damit unter anderem das HLineal im
     //				ReadonlyFall nicht angezeigt wird
     aUsrPref.SetReadonly( pWrtShell->GetViewOptions()->IsReadonly() );
 
-    //Kein Margin fuer OLE!
+    // no margin for OLE!
     Size aBrwsBorder;
     if( SFX_CREATE_MODE_EMBEDDED != pDocSh->GetCreateMode() )
         aBrwsBorder = GetMargin();
@@ -926,51 +907,18 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
         aUsrPref.SetViewVRuler(sal_False);
     }
 
-    StartListening( *pViewFrame, TRUE );
-    StartListening( *pDocSh, TRUE );
+    StartListening( *pViewFrame, sal_True );
+    StartListening( *pDocSh, sal_True );
 
-    // Vom HLineal den ZOOM-Faktor einstellen
+    // Set Zoom-factor from HLineal
     Fraction aZoomFract( aUsrPref.GetZoom(), 100 );
     pHRuler->SetZoom( aZoomFract );
     pVRuler->SetZoom( aZoomFract );
     pHRuler->SetDoubleClickHdl(LINK( this, SwView, ExecRulerClick ));
     FieldUnit eMetric = pUsrPref->GetHScrollMetric();
-
-    BOOL bApplyCharUnit = pUsrPref->IsApplyCharUnit();
-    SvtCJKOptions aCJKOptions;
-    if ( aCJKOptions.IsAsianTypographyEnabled() )
-    {
-        if ( bApplyCharUnit )
-            eMetric = FUNIT_CHAR;
-        else
-        {
-            if ( eMetric == FUNIT_CHAR )
-                eMetric = FUNIT_CM;
-        }
-    }
-    else
-    {
-        if ( eMetric == FUNIT_CHAR )
-            eMetric = FUNIT_INCH;
-    }
     pHRuler->SetUnit( eMetric );
 
     eMetric = pUsrPref->GetVScrollMetric();
-    if ( aCJKOptions.IsAsianTypographyEnabled() )
-    {
-        if ( bApplyCharUnit )
-            eMetric = FUNIT_LINE;
-        else
-        {
-            if ( eMetric == FUNIT_LINE )
-                eMetric = FUNIT_CM;
-        }
-    }
-    else
-    {
-        if ( eMetric == FUNIT_LINE )
-            eMetric = FUNIT_INCH;
-    }
     pVRuler->SetUnit( eMetric );
 
         pHRuler->SetCharWidth( 371 );  // default character width
@@ -997,12 +945,12 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
         !pDocSh->GetVisArea(ASPECT_CONTENT).IsEmpty() )
         SetVisArea( pDocSh->GetVisArea(ASPECT_CONTENT),sal_False);
 
-    SwEditShell::SetUndoActionCount(
-        static_cast< USHORT >( SW_MOD()->GetUndoOptions().GetUndoCount() ) );
-    pWrtShell->DoUndo( 0 != SwEditShell::GetUndoActionCount() );
+    pWrtShell->DoUndo( 0 != SW_MOD()->GetUndoOptions().GetUndoCount() );
 
-    const BOOL bBrowse = pWrtShell->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE);
+    const sal_Bool bBrowse = pWrtShell->GetViewOptions()->getBrowseMode();
+    // Disable "multiple window"
     SetNewWindowAllowed(!bBrowse);
+    // End of disabled multiple window
 
     ShowVScrollbar(aUsrPref.IsViewVScrollBar());
     ShowHScrollbar(aUsrPref.IsViewHScrollBar());
@@ -1032,7 +980,7 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
         SfxRequest aSfxRequest( FN_UPDATE_TOX, SFX_CALLMODE_SLOT, GetPool() );
         Execute( aSfxRequest );
         pWrtShell->GetDoc()->SetUpdateTOX( sal_False );		// wieder zurueck setzen
-        pWrtShell->SttEndDoc(TRUE);
+        pWrtShell->SttEndDoc(sal_True);
     }
 
     // kein ResetModified, wenn es schone eine View auf dieses Doc gibt
@@ -1040,14 +988,13 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
     SfxViewFrame* pFirst = SfxViewFrame::GetFirst(pDocSh);
     // zur Zeit(360) wird die View erst nach dem Ctor eingetragen
     // der folgende Ausdruck funktioniert auch, wenn sich das aendert
-    //JP 27.07.98: wenn per Undo nicht mehr die Modifizierung aufhebar ist,
+    // wenn per Undo nicht mehr die Modifizierung aufhebar ist,
     //				so setze das Modified NICHT zurueck.
-    // --> OD 2005-02-11 #i38810# - no reset of modified state, if document
+    // no reset of modified state, if document
     // was already modified.
-    if ( !pWrtShell->GetDoc()->IsUndoNoResetModified() &&
+    if (!pWrtShell->GetDoc()->GetIDocumentUndoRedo().IsUndoNoResetModified() &&
          ( !pFirst || pFirst == pVFrame ) &&
          !bIsDocModified )
-    // <--
     {
         pWrtShell->ResetModified();
     }
@@ -1062,12 +1009,7 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
         GetDispatcher().Execute(SID_NAVIGATOR, SFX_CALLMODE_ASYNCHRON, &aNavi, 0L);
     }
 
-
-    /*uno::Reference< awt::XWindow >  aTmpRef;
-    _pFrame->GetFrame().GetFrameInterface()->setComponent( aTmpRef,
-                                            pViewImpl->GetUNOObject_Impl());*/
-
-   uno::Reference< frame::XFrame >  xFrame = pVFrame->GetFrame().GetFrameInterface();
+    uno::Reference< frame::XFrame >  xFrame = pVFrame->GetFrame().GetFrameInterface();
 
     uno::Reference< frame::XFrame >  xBeamerFrame = xFrame->findFrame(
             OUString(RTL_CONSTASCII_USTRINGPARAM("_beamer")), frame::FrameSearchFlag::CHILDREN);
@@ -1091,10 +1033,10 @@ SwView::SwView( SfxViewFrame *_pFrame, SfxViewShell* pOldSh )
         pDocSh->EnableSetModified( sal_True );
     InvalidateBorder();
 
-    if( !pHScrollbar->IsVisible( TRUE ) )
-        ShowHScrollbar( FALSE );
-    if( !pVScrollbar->IsVisible( TRUE ) )
-        ShowVScrollbar( FALSE );
+    if( !pHScrollbar->IsVisible( sal_True ) )
+        ShowHScrollbar( sal_False );
+    if( !pVScrollbar->IsVisible( sal_True ) )
+        ShowVScrollbar( sal_False );
 
     GetViewFrame()->GetWindow().AddChildEventListener( LINK( this, SwView, WindowChildEventListener ) );
 }
@@ -1103,11 +1045,9 @@ SwView::~SwView()
 {
     GetViewFrame()->GetWindow().RemoveChildEventListener( LINK( this, SwView, WindowChildEventListener ) );
     delete mpPostItMgr;
-    // --> OD 2009-03-10 #i100035#
     mpPostItMgr = 0;
-    // <--
 
-    bInDtor = TRUE;
+    bInDtor = sal_True;
     pEditWin->Hide(); // damit kein Paint Aerger machen kann!
     // An der SwDocShell den Pointer auf die View ruecksetzen
     SwDocShell* pDocSh = GetDocShell();
@@ -1119,7 +1059,7 @@ SwView::~SwView()
     if( aTimer.IsActive() && bAttrChgNotifiedWithRegistrations )
         GetViewFrame()->GetBindings().LEAVEREGISTRATIONS();
 
-    //JP 27.11.00: Bug 80631 - the last view must end the text edit
+    // the last view must end the text edit
     SdrView *pSdrView = pWrtShell ? pWrtShell->GetDrawView() : 0;
     if( pSdrView && pSdrView->IsTextEdit() )
         pSdrView->SdrEndTextEdit( sal_True );
@@ -1147,9 +1087,6 @@ SwView::~SwView()
     delete pFormatClipboard;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:	DocShell rausgrabbeln ueber das FrameWindow
- --------------------------------------------------------------------*/
 SwDocShell* SwView::GetDocShell()
 {
     SfxObjectShell* pDocShell = GetViewFrame()->GetObjectShell();
@@ -1191,7 +1128,6 @@ void SwView::WriteUserData( String &rUserData, sal_Bool bBrowse )
 /*--------------------------------------------------------------------
     Beschreibung: CursorPos setzen
  --------------------------------------------------------------------*/
-//#i43146# go to the last editing position when opening own files
 bool lcl_IsOwnDocument( SwView& rView )
 {
     uno::Reference<document::XDocumentPropertiesSupplier> xDPS(
@@ -1211,9 +1147,8 @@ void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
     if ( rUserData.GetTokenCount() > 1 &&
         //Fuer Dokumente ohne Layout nur im OnlineLayout oder beim
         //Forward/Backward
-         (!pWrtShell->IsNewLayout() || pWrtShell->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) || bBrowse) )
+         (!pWrtShell->IsNewLayout() || pWrtShell->GetViewOptions()->getBrowseMode() || bBrowse) )
     {
-        //#i43146# go to the last editing position when opening own files
         bool bIsOwnDocument = lcl_IsOwnDocument( *this );
 
         SET_CURR_SHELL(pWrtShell);
@@ -1234,7 +1169,7 @@ void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
              nRight = rUserData.GetToken(0, ';', nPos ).ToInt32(),
              nBottom= rUserData.GetToken(0, ';', nPos ).ToInt32();
 
-        const long nAdd = pWrtShell->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) ? DOCUMENTBORDER : DOCUMENTBORDER*2;
+        const long nAdd = pWrtShell->GetViewOptions()->getBrowseMode() ? DOCUMENTBORDER : DOCUMENTBORDER*2;
         if ( nBottom <= (pWrtShell->GetDocSize().Height()+nAdd) )
         {
             pWrtShell->EnableSmooth( sal_False );
@@ -1243,7 +1178,7 @@ void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
 
             sal_uInt16 nOff = 0;
             SvxZoomType eZoom;
-            if( !pWrtShell->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) )
+            if( !pWrtShell->GetViewOptions()->getBrowseMode() )
                 eZoom = (SvxZoomType) (sal_uInt16)rUserData.GetToken(nOff, ';', nPos ).ToInt32();
             else
             {
@@ -1254,14 +1189,13 @@ void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
             sal_Bool bSelectObj = (0 != rUserData.GetToken( nOff, ';', nPos ).ToInt32())
                                 && pWrtShell->IsObjSelectable( aCrsrPos );
 
-            //#i33307# restore editing position
+            // restore editing position
             pViewImpl->SetRestorePosition(aCrsrPos, bSelectObj);
-            // OD 11.02.2003 #100556# - set flag value to avoid macro execution.
+            // set flag value to avoid macro execution.
             bool bSavedFlagValue = pWrtShell->IsMacroExecAllowed();
             pWrtShell->SetMacroExecAllowed( false );
-//!!! pb (11.08.2004): #i32536#
 // os: changed: The user data has to be read if the view is switched back from page preview
-//#i43146# go to the last editing position when opening own files
+// go to the last editing position when opening own files
             if(bOldShellWasPagePreView || bIsOwnDocument)
             {
                 pWrtShell->SwCrsrShell::SetCrsr( aCrsrPos, !bSelectObj );
@@ -1272,15 +1206,14 @@ void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
                 }
             }
 
-            // OD 11.02.2003 #100556# - reset flag value
+            // reset flag value
             pWrtShell->SetMacroExecAllowed( bSavedFlagValue );
 
-            // OD 08.04.2003 #108693# - set visible area before applying
+            // set visible area before applying
             // information from print preview. Otherwise, the applied information
             // is lost.
-//!!! pb (11.08.2004): #i32536#
 // os: changed: The user data has to be read if the view is switched back from page preview
-//#i43146# go to the last editing position when opening own files
+// go to the last editing position when opening own files
             if(bOldShellWasPagePreView || bIsOwnDocument )
             {
                 if ( bBrowse )
@@ -1297,7 +1230,7 @@ void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
                 Point aCrsrPos2( nXTmp, nYTmp );
                 bSelectObj = pWrtShell->IsObjSelectable( aCrsrPos2 );
 
-                pWrtShell->SwCrsrShell::SetCrsr( aCrsrPos2, FALSE );
+                pWrtShell->SwCrsrShell::SetCrsr( aCrsrPos2, sal_False );
                 if( bSelectObj )
                 {
                     pWrtShell->SelectObj( aCrsrPos2 );
@@ -1308,7 +1241,7 @@ void SwView::ReadUserData( const String &rUserData, sal_Bool bBrowse )
             }
             else if(USHRT_MAX != nNewPage)
             {
-                pWrtShell->GotoPage(nNewPage, TRUE);
+                pWrtShell->GotoPage(nNewPage, sal_True);
                 nNewPage = USHRT_MAX;
             }
 
@@ -1331,10 +1264,9 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
 {
     if(GetDocShell()->IsPreview())
         return;
-    //#i43146# go to the last editing position when opening own files
     bool bIsOwnDocument = lcl_IsOwnDocument( *this );
     sal_Int32 nLength = rSequence.getLength();
-    if (nLength && (!pWrtShell->IsNewLayout() || pWrtShell->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) || bBrowse) )
+    if (nLength && (!pWrtShell->IsNewLayout() || pWrtShell->GetViewOptions()->getBrowseMode() || bBrowse) )
     {
         SET_CURR_SHELL(pWrtShell);
         const beans::PropertyValue *pValue = rSequence.getConstArray();
@@ -1350,7 +1282,7 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
         sal_Int16 nViewLayoutColumns = pVOpt->GetViewLayoutColumns();
 
         sal_Bool bSelectedFrame = ( pWrtShell->GetSelFrmType() != FRMTYPE_NONE ),
-                 bGotViewLeft = sal_False, bGotViewTop = sal_False, bGotVisibleLeft = sal_False,
+                 bGotVisibleLeft = sal_False,
                  bGotVisibleTop = sal_False, bGotVisibleRight = sal_False,
                  bGotVisibleBottom = sal_False, bGotZoomType = sal_False,
                  bGotZoomFactor = sal_False, bGotIsSelectedFrame = sal_False,
@@ -1362,13 +1294,11 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
             {
                pValue->Value >>= nX;
                nX = MM100_TO_TWIP( nX );
-               bGotViewLeft = sal_True;
             }
             else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "ViewTop" ) ) )
             {
                pValue->Value >>= nY;
                nY = MM100_TO_TWIP( nY );
-               bGotViewTop = sal_True;
             }
             else if (pValue->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "VisibleLeft" ) ) )
             {
@@ -1424,7 +1354,7 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
         if (bGotVisibleBottom)
         {
             Point aCrsrPos( nX, nY );
-            const long nAdd = pWrtShell->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) ? DOCUMENTBORDER : DOCUMENTBORDER*2;
+            const long nAdd = pWrtShell->GetViewOptions()->getBrowseMode() ? DOCUMENTBORDER : DOCUMENTBORDER*2;
             if (nBottom <= (pWrtShell->GetDocSize().Height()+nAdd) )
             {
                 pWrtShell->EnableSmooth( sal_False );
@@ -1432,7 +1362,7 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
 
                 sal_uInt16 nOff = 0;
                 SvxZoomType eZoom;
-                if ( !pWrtShell->getIDocumentSettingAccess()->get(IDocumentSettingAccess::BROWSE_MODE) )
+                if ( !pWrtShell->GetViewOptions()->getBrowseMode() )
                     eZoom = static_cast < SvxZoomType > ( nZoomType );
                 else
                 {
@@ -1444,13 +1374,11 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
                     sal_Bool bSelectObj = (sal_False != bSelectedFrame )
                                         && pWrtShell->IsObjSelectable( aCrsrPos );
 
-                    // OD 11.02.2003 #100556# - set flag value to avoid macro execution.
+                    // set flag value to avoid macro execution.
                     bool bSavedFlagValue = pWrtShell->IsMacroExecAllowed();
                     pWrtShell->SetMacroExecAllowed( false );
-//!!! pb (11.08.2004): #i32536#
 // os: changed: The user data has to be read if the view is switched back from page preview
-//#i43146# go to the last editing position when opening own files
-                    //#i33307# restore editing position
+// go to the last editing position when opening own files
                     pViewImpl->SetRestorePosition(aCrsrPos, bSelectObj);
                     if(bOldShellWasPagePreView|| bIsOwnDocument)
                     {
@@ -1462,7 +1390,7 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
                         }
                     }
 
-                    // OD 11.02.2003 #100556# - reset flag value
+                    // reset flag value
                     pWrtShell->SetMacroExecAllowed( bSavedFlagValue );
                 }
                 SelectShell();
@@ -1483,7 +1411,6 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
                                                   bSetViewSettings &&
                                                   eZoom != SVX_ZOOM_PERCENT;
 
-
                 if ( !bZoomNeedsViewLayout )
                     pWrtShell->StartAction();
 
@@ -1496,15 +1423,14 @@ void SwView::ReadUserDataSequence ( const uno::Sequence < beans::PropertyValue >
                 if ( bSetViewSettings )
                     SetZoom( eZoom, nZoomFactor, sal_True );
 
-//!!! pb (11.08.2004): #i32536#
 // os: changed: The user data has to be read if the view is switched back from page preview
-//#i43146# go to the last editing position when opening own files
+// go to the last editing position when opening own files
                 if(bOldShellWasPagePreView||bIsOwnDocument)
                 {
                     if ( bBrowse && bGotVisibleLeft && bGotVisibleTop )
                     {
                         Point aTopLeft(aVis.TopLeft());
-                        //#i76699# make sure the document is still centered
+                        // make sure the document is still centered
                         const SwTwips lBorder = IsDocumentBorder() ? DOCUMENTBORDER : 2 * DOCUMENTBORDER;
                         SwTwips nEditWidth = GetEditWin().GetOutputSize().Width();
                         if(nEditWidth > (aDocSz.Width() + lBorder ))
@@ -1604,9 +1530,9 @@ void SwView::WriteUserDataSequence ( uno::Sequence < beans::PropertyValue >& rSe
 
 void SwView::ShowCursor( bool bOn )
 {
-    //JP 10.10.2001: Bug 90461 - don't scroll the cursor into the visible area
-    BOOL bUnlockView = !pWrtShell->IsViewLocked();
-    pWrtShell->LockView( TRUE );	//lock visible section
+    //don't scroll the cursor into the visible area
+    sal_Bool bUnlockView = !pWrtShell->IsViewLocked();
+    pWrtShell->LockView( sal_True );	//lock visible section
 
     if( !bOn )
         pWrtShell->HideCrsr();
@@ -1614,7 +1540,7 @@ void SwView::ShowCursor( bool bOn )
         pWrtShell->ShowCrsr();
 
     if( bUnlockView )
-        pWrtShell->LockView( FALSE );
+        pWrtShell->LockView( sal_False );
 }
 
 ErrCode SwView::DoVerb( long nVerb )
@@ -1629,9 +1555,8 @@ ErrCode SwView::DoVerb( long nVerb )
     return ERRCODE_NONE;
 }
 
-/*-----------------17.02.98 13:33-------------------
-    nur sal_True fuer eine Textselektion zurueck geben
---------------------------------------------------*/
+/*   only return sal_True for a text selection
+*/
 sal_Bool SwView::HasSelection( sal_Bool  bText ) const
 {
     return bText ? GetWrtShell().SwCrsrShell::HasSelection()
@@ -1665,13 +1590,13 @@ SwGlossaryHdl* SwView::GetGlosHdl()
 
 void SwView::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
 {
-    BOOL bCallBase = sal_True;
+    sal_Bool bCallBase = sal_True;
     if ( rHint.ISA(SfxSimpleHint) )
     {
         sal_uInt32 nId = ((SfxSimpleHint&)rHint).GetId();
         switch ( nId )
         {
-            // --> OD 2005-03-03 #i43775# - sub shells will be destroyed by the
+            // sub shells will be destroyed by the
             // dispatcher, if the view frame is dying. Thus, reset member <pShell>.
             case SFX_HINT_DYING:
                 {
@@ -1681,7 +1606,6 @@ void SwView::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
                     }
                 }
                 break;
-            // <--
             case SFX_HINT_MODECHANGED:
                 {
                     // Modalmodus-Umschaltung?
@@ -1690,7 +1614,7 @@ void SwView::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
                     pVRuler->SetActive( !bModal );
                 }
 
-                /* kein break hier */
+                /* no break here */
 
             case SFX_HINT_TITLECHANGED:
                 if ( GetDocShell()->IsReadOnly() != GetWrtShell().GetViewOptions()->IsReadonly() )
@@ -1707,7 +1631,7 @@ void SwView::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
                     else
                         KillTab();
                     bool bReadonly = GetDocShell()->IsReadOnly();
-                    //#i76332# if document is to be opened in alive-mode then this has to be regarded while switching from readonly-mode to edit-mode
+                    // if document is to be opened in alive-mode then this has to be regarded while switching from readonly-mode to edit-mode
                     if( !bReadonly )
                     {
                         SwDrawDocument * pDrawDoc = 0;
@@ -1754,7 +1678,7 @@ void SwView::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
         SfxViewShell::Notify(rBC, rHint);
 }
 
-#if defined WIN || defined WNT || defined UNX
+#if defined WNT || defined UNX
 
 void SwView::ScannerEventHdl( const EventObject& /*rEventObject*/ )
 {
@@ -1820,9 +1744,9 @@ sal_uInt16  SwView::PrepareClose( sal_Bool bUI, sal_Bool bForBrowsing )
 
 // status methods for clipboard.
 // Status changes now notified from the clipboard.
-BOOL SwView::IsPasteAllowed()
+sal_Bool SwView::IsPasteAllowed()
 {
-    USHORT nPasteDestination = SwTransferable::GetSotDestination( *pWrtShell );
+    sal_uInt16 nPasteDestination = SwTransferable::GetSotDestination( *pWrtShell );
     if( nLastPasteDestination != nPasteDestination )
     {
         TransferableDataHelper aDataHelper(
@@ -1835,7 +1759,7 @@ BOOL SwView::IsPasteAllowed()
                                                     *pWrtShell, aDataHelper );
         }
         else
-            bPasteState = bPasteSpecialState = FALSE;
+            bPasteState = bPasteSpecialState = sal_False;
 
         if( 0xFFFF == nLastPasteDestination )  // the init value
             pViewImpl->AddClipboardListener();
@@ -1844,12 +1768,12 @@ BOOL SwView::IsPasteAllowed()
     return bPasteState;
 }
 
-BOOL SwView::IsPasteSpecialAllowed()
+sal_Bool SwView::IsPasteSpecialAllowed()
 {
     if ( pFormShell && pFormShell->IsActiveControl() )
-        return FALSE;
+        return sal_False;
 
-    USHORT nPasteDestination = SwTransferable::GetSotDestination( *pWrtShell );
+    sal_uInt16 nPasteDestination = SwTransferable::GetSotDestination( *pWrtShell );
     if( nLastPasteDestination != nPasteDestination )
     {
         TransferableDataHelper aDataHelper(
@@ -1862,7 +1786,7 @@ BOOL SwView::IsPasteSpecialAllowed()
                                                     *pWrtShell, aDataHelper );
         }
         else
-            bPasteState = bPasteSpecialState = FALSE;
+            bPasteState = bPasteSpecialState = sal_False;
 
         if( 0xFFFF == nLastPasteDestination )  // the init value
             pViewImpl->AddClipboardListener();
@@ -1878,19 +1802,18 @@ void SwView::NotifyDBChanged()
 /*--------------------------------------------------------------------
     Beschreibung:   Drucken
  --------------------------------------------------------------------*/
-SfxObjectShellRef & SwView::GetTmpSelectionDoc()
+SfxObjectShellLock & SwView::GetTmpSelectionDoc()
 {
     return GetViewImpl()->GetTmpSelectionDoc();
 }
 
-SfxObjectShellRef & SwView::GetOrCreateTmpSelectionDoc()
+SfxObjectShellLock & SwView::GetOrCreateTmpSelectionDoc()
 {
-    SfxObjectShellRef &rxTmpDoc = GetViewImpl()->GetTmpSelectionDoc();
+    SfxObjectShellLock &rxTmpDoc = GetViewImpl()->GetTmpSelectionDoc();
     if (!rxTmpDoc.Is())
     {
         SwXTextView *pImpl = GetViewImpl()->GetUNOObject_Impl();
-        rxTmpDoc = pImpl->BuildTmpSelectionDoc(
-                    GetViewImpl()->GetEmbeddedObjRef() );
+        rxTmpDoc = pImpl->BuildTmpSelectionDoc();
     }
     return rxTmpDoc;
 }
@@ -1900,18 +1823,13 @@ void SwView::AddTransferable(SwTransferable& rTransferable)
     GetViewImpl()->AddTransferable(rTransferable);
 }
 
-void SwPrtOptions::MakeOptions( BOOL bWeb )
+namespace sw {
+
+void InitPrintOptionsFromApplication(SwPrintData & o_rData, bool const bWeb)
 {
-    *this = *SW_MOD()->GetPrtOptions(bWeb);
-
-    nCopyCount = 1;
-    bCollate = FALSE;
-    bPrintSelection = FALSE;
-    bJobStartet = FALSE;
-
-    aMulti.SetTotalRange( Range( 0, RANGE_MAX ) );
-    aMulti.SelectAll();
-    aMulti.Select( 0, FALSE );
+    o_rData = *SW_MOD()->GetPrtOptions(bWeb);
 }
 
+} // namespace sw
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
